'''
Copyright (c) 2020 epiphani, Inc.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
'''
# This is an auto-generated file, please do not modify

SUBSCRIPTIONS = {'oncreatealertapikey': '\n'
                        '  subscription OnCreateAlertApiKey {\n'
                        '    onCreateAlertApiKey {\n'
                        '      id\n'
                        '      alertsPbName\n'
                        '      createdAt\n'
                        '      updatedAt\n'
                        '      author\n'
                        '    }\n'
                        '  }\n',
 'oncreateallrunbooks': '\n'
                        '  subscription OnCreateAllRunbooks {\n'
                        '    onCreateAllRunbooks {\n'
                        '      id\n'
                        '      name\n'
                        '      description\n'
                        '      content\n'
                        '      author\n'
                        '      commands\n'
                        '      createdAt\n'
                        '      updatedAt\n'
                        '      RunBookConnectors\n'
                        '      type\n'
                        '      longSave\n'
                        '      rbVars\n'
                        '      scope\n'
                        '      PeopleCanView\n'
                        '      PeopleCanAccess\n'
                        '      GroupsCanView\n'
                        '      GroupsCanAccess\n'
                        '      connectorForms {\n'
                        '        nextToken\n'
                        '      }\n'
                        '    }\n'
                        '  }\n',
 'oncreateallworkflows': '\n'
                         '  subscription OnCreateAllWorkflows {\n'
                         '    onCreateAllWorkflows {\n'
                         '      id\n'
                         '      createdAt\n'
                         '      updatedAt\n'
                         '      name\n'
                         '      description\n'
                         '      type\n'
                         '      author\n'
                         '      longSave\n'
                         '      rbVars\n'
                         '    }\n'
                         '  }\n',
 'oncreatebase64image': '\n'
                        '  subscription OnCreateBase64Image {\n'
                        '    onCreateBase64Image {\n'
                        '      id\n'
                        '      playbookID\n'
                        '      base64String\n'
                        '    }\n'
                        '  }\n',
 'oncreatechannel': '\n'
                    '  subscription OnCreateChannel {\n'
                    '    onCreateChannel {\n'
                    '      id\n'
                    '      messages {\n'
                    '        nextToken\n'
                    '      }\n'
                    '      associated {\n'
                    '        nextToken\n'
                    '      }\n'
                    '      name\n'
                    '      title\n'
                    '      members\n'
                    '      membersState\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '      memberLocation\n'
                    '    }\n'
                    '  }\n',
 'oncreatechat': '\n'
                 '  subscription OnCreateChat {\n'
                 '    onCreateChat {\n'
                 '      id\n'
                 '      from\n'
                 '      content\n'
                 '      createdAt\n'
                 '    }\n'
                 '  }\n',
 'oncreatecheatsheet': '\n'
                       '  subscription OnCreateCheatSheet {\n'
                       '    onCreateCheatSheet {\n'
                       '      id\n'
                       '      createdAt\n'
                       '      updatedAt\n'
                       '      title\n'
                       '      author\n'
                       '      content\n'
                       '      type\n'
                       '    }\n'
                       '  }\n',
 'oncreatechecklist': '\n'
                      '  subscription OnCreateCheckList {\n'
                      '    onCreateCheckList {\n'
                      '      id\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '      name\n'
                      '      description\n'
                      '      type\n'
                      '      content\n'
                      '      author\n'
                      '      CheckListLink {\n'
                      '        nextToken\n'
                      '      }\n'
                      '      CheckListInvLink {\n'
                      '        nextToken\n'
                      '      }\n'
                      '    }\n'
                      '  }\n',
 'oncreatechecklistinvlink': '\n'
                             '  subscription OnCreateCheckListInvLink($owner: '
                             'String) {\n'
                             '    onCreateCheckListInvLink(owner: $owner) {\n'
                             '      id\n'
                             '      createdAt\n'
                             '      updatedAt\n'
                             '      investigationID\n'
                             '      CheckListID\n'
                             '      CheckList {\n'
                             '        id\n'
                             '        createdAt\n'
                             '        updatedAt\n'
                             '        name\n'
                             '        description\n'
                             '        type\n'
                             '        content\n'
                             '        author\n'
                             '      }\n'
                             '      investigation {\n'
                             '        id\n'
                             '        title\n'
                             '        from\n'
                             '        createdAt\n'
                             '        currentState\n'
                             '        HumanID\n'
                             '        currentStateID\n'
                             '        severity\n'
                             '        priority\n'
                             '        location\n'
                             '        channelId\n'
                             '        updatedAt\n'
                             '        resolvedTime\n'
                             '        resolvedComment\n'
                             '        Symptoms\n'
                             '        meetingType\n'
                             '        meetingId\n'
                             '      }\n'
                             '      owner\n'
                             '    }\n'
                             '  }\n',
 'oncreatechecklistitem': '\n'
                          '  subscription OnCreateCheckListItem {\n'
                          '    onCreateCheckListItem {\n'
                          '      id\n'
                          '      localID\n'
                          '      createdAt\n'
                          '      updatedAt\n'
                          '      author\n'
                          '      content\n'
                          '      title\n'
                          '      type\n'
                          '      connection\n'
                          '      MMNodeConnection\n'
                          '      investigationID\n'
                          '      assignee\n'
                          '      associatedPlaybooks\n'
                          '      associatedCommands\n'
                          '      CheckListLink {\n'
                          '        nextToken\n'
                          '      }\n'
                          '    }\n'
                          '  }\n',
 'oncreateclick': '\n'
                  '  subscription OnCreateClick {\n'
                  '    onCreateClick {\n'
                  '      id\n'
                  '      count\n'
                  '      type\n'
                  '      featureName\n'
                  '      createdAt\n'
                  '      updatedAt\n'
                  '      readAt\n'
                  '    }\n'
                  '  }\n',
 'oncreateclicllink': '\n'
                      '  subscription OnCreateCliclLink($author: String) {\n'
                      '    onCreateCLICLLink(author: $author) {\n'
                      '      id\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '      CheckListItemID\n'
                      '      lane\n'
                      '      CheckListID\n'
                      '      CheckList {\n'
                      '        id\n'
                      '        createdAt\n'
                      '        updatedAt\n'
                      '        name\n'
                      '        description\n'
                      '        type\n'
                      '        content\n'
                      '        author\n'
                      '      }\n'
                      '      CheckListItem {\n'
                      '        id\n'
                      '        localID\n'
                      '        createdAt\n'
                      '        updatedAt\n'
                      '        author\n'
                      '        content\n'
                      '        title\n'
                      '        type\n'
                      '        connection\n'
                      '        MMNodeConnection\n'
                      '        investigationID\n'
                      '        assignee\n'
                      '        associatedPlaybooks\n'
                      '        associatedCommands\n'
                      '      }\n'
                      '    }\n'
                      '  }\n',
 'oncreatecommands': '\n'
                     '  subscription OnCreateCommands {\n'
                     '    onCreateCommands {\n'
                     '      id\n'
                     '      from\n'
                     '      mode\n'
                     '      command\n'
                     '      output\n'
                     '      state\n'
                     '      returnCode\n'
                     '      investigationId\n'
                     '      createdAt\n'
                     '      updatedAt\n'
                     '      investigation {\n'
                     '        id\n'
                     '        title\n'
                     '        from\n'
                     '        createdAt\n'
                     '        currentState\n'
                     '        HumanID\n'
                     '        currentStateID\n'
                     '        severity\n'
                     '        priority\n'
                     '        location\n'
                     '        channelId\n'
                     '        updatedAt\n'
                     '        resolvedTime\n'
                     '        resolvedComment\n'
                     '        Symptoms\n'
                     '        meetingType\n'
                     '        meetingId\n'
                     '      }\n'
                     '    }\n'
                     '  }\n',
 'oncreatecomment': '\n'
                    '  subscription OnCreateComment {\n'
                    '    onCreateComment {\n'
                    '      id\n'
                    '      parent\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '      author\n'
                    '      content\n'
                    '      type\n'
                    '      links\n'
                    '      investigationId\n'
                    '      investigation {\n'
                    '        id\n'
                    '        title\n'
                    '        from\n'
                    '        createdAt\n'
                    '        currentState\n'
                    '        HumanID\n'
                    '        currentStateID\n'
                    '        severity\n'
                    '        priority\n'
                    '        location\n'
                    '        channelId\n'
                    '        updatedAt\n'
                    '        resolvedTime\n'
                    '        resolvedComment\n'
                    '        Symptoms\n'
                    '        meetingType\n'
                    '        meetingId\n'
                    '      }\n'
                    '    }\n'
                    '  }\n',
 'oncreateconferenceconfig': '\n'
                             '  subscription OnCreateConferenceConfig {\n'
                             '    onCreateConferenceConfig {\n'
                             '      id\n'
                             '      url\n'
                             '      userName\n'
                             '      password\n'
                             '      author\n'
                             '      createdAt\n'
                             '      updatedAt\n'
                             '    }\n'
                             '  }\n',
 'oncreateconnectorform': '\n'
                          '  subscription OnCreateConnectorForm {\n'
                          '    onCreateConnectorForm {\n'
                          '      id\n'
                          '      createdAt\n'
                          '      updatedAt\n'
                          '      name\n'
                          '      owner\n'
                          '      connectorID\n'
                          '      connector {\n'
                          '        id\n'
                          '        createdAt\n'
                          '        updatedAt\n'
                          '        category\n'
                          '        name\n'
                          '        owner\n'
                          '        description\n'
                          '        detaileddescription\n'
                          '        iconPath\n'
                          '        version\n'
                          '        md5\n'
                          '        source\n'
                          '        configuration\n'
                          '        commands\n'
                          '        commandsType\n'
                          '        script\n'
                          '        scriptType\n'
                          '        scriptPath\n'
                          '        scope\n'
                          '        PeopleCanView\n'
                          '        PeopleCanAccess\n'
                          '        GroupsCanView\n'
                          '        GroupsCanAccess\n'
                          '      }\n'
                          '      configData\n'
                          '      commandData\n'
                          '      nodeData\n'
                          '      scope\n'
                          '      PeopleCanView\n'
                          '      PeopleCanAccess\n'
                          '      GroupsCanView\n'
                          '      GroupsCanAccess\n'
                          '      runbooks {\n'
                          '        nextToken\n'
                          '      }\n'
                          '    }\n'
                          '  }\n',
 'oncreateconnectors': '\n'
                       '  subscription OnCreateConnectors {\n'
                       '    onCreateConnectors {\n'
                       '      id\n'
                       '      createdAt\n'
                       '      updatedAt\n'
                       '      category\n'
                       '      name\n'
                       '      owner\n'
                       '      description\n'
                       '      detaileddescription\n'
                       '      iconPath\n'
                       '      version\n'
                       '      md5\n'
                       '      source\n'
                       '      configuration\n'
                       '      commands\n'
                       '      commandsType\n'
                       '      script\n'
                       '      scriptType\n'
                       '      scriptPath\n'
                       '      scope\n'
                       '      PeopleCanView\n'
                       '      PeopleCanAccess\n'
                       '      GroupsCanView\n'
                       '      GroupsCanAccess\n'
                       '    }\n'
                       '  }\n',
 'oncreatedashboardconfig': '\n'
                            '  subscription OnCreateDashboardConfig {\n'
                            '    onCreateDashboardConfig {\n'
                            '      id\n'
                            '      url\n'
                            '      labels {\n'
                            '        nextToken\n'
                            '      }\n'
                            '      author\n'
                            '      createdAt\n'
                            '      updatedAt\n'
                            '    }\n'
                            '  }\n',
 'oncreateecubesandboxexecution': '\n'
                                  '  subscription '
                                  'OnCreateEcubeSandboxExecution {\n'
                                  '    onCreateEcubeSandboxExecution {\n'
                                  '      id\n'
                                  '      owner\n'
                                  '      output\n'
                                  '      outputType\n'
                                  '      returnCode\n'
                                  '      status\n'
                                  '      createdAt\n'
                                  '      updatedAt\n'
                                  '      E3One\n'
                                  '      E3Two\n'
                                  '      E3Three\n'
                                  '    }\n'
                                  '  }\n',
 'oncreateepicautocomplete': '\n'
                             '  subscription OnCreateEpicAutoComplete($author: '
                             'String) {\n'
                             '    onCreateEpicAutoComplete(author: $author) {\n'
                             '      id\n'
                             '      author\n'
                             '      cliCommand\n'
                             '      command\n'
                             '      createdAt\n'
                             '      updatedAt\n'
                             '      investigationId\n'
                             '      times\n'
                             '    }\n'
                             '  }\n',
 'oncreateepiclicommand': '\n'
                          '  subscription OnCreateEpicliCommand {\n'
                          '    onCreateEPICLICommand {\n'
                          '      id\n'
                          '      createdAt\n'
                          '      updatedAt\n'
                          '      author\n'
                          '      content\n'
                          '      type\n'
                          '    }\n'
                          '  }\n',
 'oncreateexecutedrunbooks': '\n'
                             '  subscription OnCreateExecutedRunbooks {\n'
                             '    onCreateExecutedRunbooks {\n'
                             '      id\n'
                             '      createdAt\n'
                             '      updatedAt\n'
                             '      runbookID\n'
                             '      investigationId\n'
                             '      output\n'
                             '      outputType\n'
                             '      title\n'
                             '      state\n'
                             '      author\n'
                             '      rbVars\n'
                             '      callbackUrl\n'
                             '      callbackData\n'
                             '      source\n'
                             '      investigation {\n'
                             '        id\n'
                             '        title\n'
                             '        from\n'
                             '        createdAt\n'
                             '        currentState\n'
                             '        HumanID\n'
                             '        currentStateID\n'
                             '        severity\n'
                             '        priority\n'
                             '        location\n'
                             '        channelId\n'
                             '        updatedAt\n'
                             '        resolvedTime\n'
                             '        resolvedComment\n'
                             '        Symptoms\n'
                             '        meetingType\n'
                             '        meetingId\n'
                             '      }\n'
                             '      runbook {\n'
                             '        id\n'
                             '        name\n'
                             '        description\n'
                             '        content\n'
                             '        author\n'
                             '        commands\n'
                             '        createdAt\n'
                             '        updatedAt\n'
                             '        RunBookConnectors\n'
                             '        type\n'
                             '        longSave\n'
                             '        rbVars\n'
                             '        scope\n'
                             '        PeopleCanView\n'
                             '        PeopleCanAccess\n'
                             '        GroupsCanView\n'
                             '        GroupsCanAccess\n'
                             '      }\n'
                             '    }\n'
                             '  }\n',
 'oncreateexecutedworkflowstate': '\n'
                                  '  subscription '
                                  'OnCreateExecutedWorkflowState {\n'
                                  '    onCreateExecutedWorkflowState {\n'
                                  '      id\n'
                                  '      createdAt\n'
                                  '      updatedAt\n'
                                  '      name\n'
                                  '      state\n'
                                  '      output\n'
                                  '      type\n'
                                  '      allworkflowID\n'
                                  '      investigationID\n'
                                  '      investigation {\n'
                                  '        id\n'
                                  '        title\n'
                                  '        from\n'
                                  '        createdAt\n'
                                  '        currentState\n'
                                  '        HumanID\n'
                                  '        currentStateID\n'
                                  '        severity\n'
                                  '        priority\n'
                                  '        location\n'
                                  '        channelId\n'
                                  '        updatedAt\n'
                                  '        resolvedTime\n'
                                  '        resolvedComment\n'
                                  '        Symptoms\n'
                                  '        meetingType\n'
                                  '        meetingId\n'
                                  '      }\n'
                                  '    }\n'
                                  '  }\n',
 'oncreategroupmember': '\n'
                        '  subscription OnCreateGroupMember {\n'
                        '    onCreateGroupMember {\n'
                        '      id\n'
                        '      hostId\n'
                        '      groupId\n'
                        '      host {\n'
                        '        id\n'
                        '        inventoryId\n'
                        '        createdAt\n'
                        '        updatedAt\n'
                        '        author\n'
                        '        host\n'
                        '        port\n'
                        '        vars\n'
                        '      }\n'
                        '      group {\n'
                        '        id\n'
                        '        inventoryId\n'
                        '        createdAt\n'
                        '        updatedAt\n'
                        '        author\n'
                        '        name\n'
                        '        groups\n'
                        '        port\n'
                        '        vars\n'
                        '      }\n'
                        '    }\n'
                        '  }\n',
 'oncreateguardrail': '\n'
                      '  subscription OnCreateGuardRail {\n'
                      '    onCreateGuardRail {\n'
                      '      id\n'
                      '      timeOut\n'
                      '      message\n'
                      '      labels {\n'
                      '        nextToken\n'
                      '      }\n'
                      '      author\n'
                      '      active\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '    }\n'
                      '  }\n',
 'oncreatehint': '\n'
                 '  subscription OnCreateHint {\n'
                 '    onCreateHint {\n'
                 '      id\n'
                 '      investigationId\n'
                 '      createdAt\n'
                 '      updatedAt\n'
                 '      type\n'
                 '      connection\n'
                 '      pastInvestigationID\n'
                 '      title\n'
                 '      importance\n'
                 '      starrted\n'
                 '      applied\n'
                 '      url\n'
                 '      why\n'
                 '    }\n'
                 '  }\n',
 'oncreateinventory': '\n'
                      '  subscription OnCreateInventory {\n'
                      '    onCreateInventory {\n'
                      '      id\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '      author\n'
                      '      name\n'
                      '      all {\n'
                      '        nextToken\n'
                      '      }\n'
                      '      groups {\n'
                      '        nextToken\n'
                      '      }\n'
                      '      vars\n'
                      '    }\n'
                      '  }\n',
 'oncreateinventorygroup': '\n'
                           '  subscription OnCreateInventoryGroup {\n'
                           '    onCreateInventoryGroup {\n'
                           '      id\n'
                           '      inventoryId\n'
                           '      createdAt\n'
                           '      updatedAt\n'
                           '      author\n'
                           '      name\n'
                           '      hosts {\n'
                           '        nextToken\n'
                           '      }\n'
                           '      groups\n'
                           '      port\n'
                           '      vars\n'
                           '      inventory {\n'
                           '        id\n'
                           '        createdAt\n'
                           '        updatedAt\n'
                           '        author\n'
                           '        name\n'
                           '        vars\n'
                           '      }\n'
                           '    }\n'
                           '  }\n',
 'oncreateinventoryhost': '\n'
                          '  subscription OnCreateInventoryHost {\n'
                          '    onCreateInventoryHost {\n'
                          '      id\n'
                          '      inventoryId\n'
                          '      createdAt\n'
                          '      updatedAt\n'
                          '      author\n'
                          '      host\n'
                          '      port\n'
                          '      vars\n'
                          '      groups {\n'
                          '        nextToken\n'
                          '      }\n'
                          '      inventory {\n'
                          '        id\n'
                          '        createdAt\n'
                          '        updatedAt\n'
                          '        author\n'
                          '        name\n'
                          '        vars\n'
                          '      }\n'
                          '    }\n'
                          '  }\n',
 'oncreateinvestigation': '\n'
                          '  subscription OnCreateInvestigation {\n'
                          '    onCreateInvestigation {\n'
                          '      id\n'
                          '      title\n'
                          '      from\n'
                          '      createdAt\n'
                          '      currentState\n'
                          '      HumanID\n'
                          '      currentStateID\n'
                          '      severity\n'
                          '      priority\n'
                          '      location\n'
                          '      labels {\n'
                          '        nextToken\n'
                          '      }\n'
                          '      channelId\n'
                          '      investigationChannel {\n'
                          '        id\n'
                          '        name\n'
                          '        title\n'
                          '        members\n'
                          '        membersState\n'
                          '        createdAt\n'
                          '        updatedAt\n'
                          '        memberLocation\n'
                          '      }\n'
                          '      updatedAt\n'
                          '      resolvedTime\n'
                          '      resolvedComment\n'
                          '      Symptoms\n'
                          '      MMNodeLinks {\n'
                          '        nextToken\n'
                          '      }\n'
                          '      CheckListInvLink {\n'
                          '        nextToken\n'
                          '      }\n'
                          '      meetingType\n'
                          '      meetingId\n'
                          '    }\n'
                          '  }\n',
 'oncreateinvestigationevent': '\n'
                               '  subscription OnCreateInvestigationEvent {\n'
                               '    onCreateInvestigationEvent {\n'
                               '      id\n'
                               '      createdAt\n'
                               '      updatedAt\n'
                               '      author\n'
                               '      content\n'
                               '      type\n'
                               '      links\n'
                               '      investigationId\n'
                               '      investigation {\n'
                               '        id\n'
                               '        title\n'
                               '        from\n'
                               '        createdAt\n'
                               '        currentState\n'
                               '        HumanID\n'
                               '        currentStateID\n'
                               '        severity\n'
                               '        priority\n'
                               '        location\n'
                               '        channelId\n'
                               '        updatedAt\n'
                               '        resolvedTime\n'
                               '        resolvedComment\n'
                               '        Symptoms\n'
                               '        meetingType\n'
                               '        meetingId\n'
                               '      }\n'
                               '    }\n'
                               '  }\n',
 'oncreateinvestigationguestuserlink': '\n'
                                       '  subscription '
                                       'OnCreateInvestigationGuestUserLink {\n'
                                       '    onCreateInvestigationGuestUserLink '
                                       '{\n'
                                       '      id\n'
                                       '      userName\n'
                                       '      createdAt\n'
                                       '      updatedAt\n'
                                       '      investigationID\n'
                                       '      channelID\n'
                                       '    }\n'
                                       '  }\n',
 'oncreatelabel': '\n'
                  '  subscription OnCreateLabel {\n'
                  '    onCreateLabel {\n'
                  '      id\n'
                  '      name\n'
                  '      color\n'
                  '      type\n'
                  '      investigations {\n'
                  '        nextToken\n'
                  '      }\n'
                  '      userSettings {\n'
                  '        nextToken\n'
                  '      }\n'
                  '    }\n'
                  '  }\n',
 'oncreateleadboard': '\n'
                      '  subscription OnCreateLeadBoard {\n'
                      '    onCreateLeadBoard {\n'
                      '      id\n'
                      '      investigationId\n'
                      '      content\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '      investigation {\n'
                      '        id\n'
                      '        title\n'
                      '        from\n'
                      '        createdAt\n'
                      '        currentState\n'
                      '        HumanID\n'
                      '        currentStateID\n'
                      '        severity\n'
                      '        priority\n'
                      '        location\n'
                      '        channelId\n'
                      '        updatedAt\n'
                      '        resolvedTime\n'
                      '        resolvedComment\n'
                      '        Symptoms\n'
                      '        meetingType\n'
                      '        meetingId\n'
                      '      }\n'
                      '    }\n'
                      '  }\n',
 'oncreateleadboardnode': '\n'
                          '  subscription OnCreateLeadBoardNode {\n'
                          '    onCreateLeadBoardNode {\n'
                          '      id\n'
                          '      localID\n'
                          '      createdAt\n'
                          '      updatedAt\n'
                          '      author\n'
                          '      content\n'
                          '      title\n'
                          '      notes\n'
                          '      associatedPlaybooks\n'
                          '      associatedCommands\n'
                          '      InvestLinks {\n'
                          '        nextToken\n'
                          '      }\n'
                          '    }\n'
                          '  }\n',
 'oncreatemessage': '\n'
                    '  subscription OnCreateMessage {\n'
                    '    onCreateMessage {\n'
                    '      id\n'
                    '      authorId\n'
                    '      content\n'
                    '      type\n'
                    '      channel {\n'
                    '        id\n'
                    '        name\n'
                    '        title\n'
                    '        members\n'
                    '        membersState\n'
                    '        createdAt\n'
                    '        updatedAt\n'
                    '        memberLocation\n'
                    '      }\n'
                    '      messageChannelId\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '      author {\n'
                    '        id\n'
                    '        username\n'
                    '        email\n'
                    '        firstname\n'
                    '        lastname\n'
                    '        avatar\n'
                    '        mood\n'
                    '        name\n'
                    '        role\n'
                    '        status\n'
                    '        timezone\n'
                    '        phone\n'
                    '        address\n'
                    '        location\n'
                    '        createdAt\n'
                    '        updatedAt\n'
                    '        owner\n'
                    '      }\n'
                    '    }\n'
                    '  }\n',
 'oncreatemmnodelink': '\n'
                       '  subscription OnCreateMmNodeLink {\n'
                       '    onCreateMMNodeLink {\n'
                       '      id\n'
                       '      createdAt\n'
                       '      updatedAt\n'
                       '      assigned\n'
                       '      state\n'
                       '      content\n'
                       '      author\n'
                       '      investigationID\n'
                       '      connectionToTask\n'
                       '      LBNID\n'
                       '      LeadBoardNodeId {\n'
                       '        id\n'
                       '        localID\n'
                       '        createdAt\n'
                       '        updatedAt\n'
                       '        author\n'
                       '        content\n'
                       '        title\n'
                       '        notes\n'
                       '        associatedPlaybooks\n'
                       '        associatedCommands\n'
                       '      }\n'
                       '      investigationId {\n'
                       '        id\n'
                       '        title\n'
                       '        from\n'
                       '        createdAt\n'
                       '        currentState\n'
                       '        HumanID\n'
                       '        currentStateID\n'
                       '        severity\n'
                       '        priority\n'
                       '        location\n'
                       '        channelId\n'
                       '        updatedAt\n'
                       '        resolvedTime\n'
                       '        resolvedComment\n'
                       '        Symptoms\n'
                       '        meetingType\n'
                       '        meetingId\n'
                       '      }\n'
                       '    }\n'
                       '  }\n',
 'oncreatenotification': '\n'
                         '  subscription OnCreateNotification {\n'
                         '    onCreateNotification {\n'
                         '      id\n'
                         '      userName\n'
                         '      content\n'
                         '      containerType\n'
                         '      containerId\n'
                         '      investigationId\n'
                         '      isViewed\n'
                         '      createdAt\n'
                         '      updatedAt\n'
                         '    }\n'
                         '  }\n',
 'oncreatepin': '\n'
                '  subscription OnCreatePin {\n'
                '    onCreatePin {\n'
                '      id\n'
                '      imageId\n'
                '      content\n'
                '      createdAt\n'
                '      updatedAt\n'
                '      author\n'
                '      investigationId\n'
                '      investigation {\n'
                '        id\n'
                '        title\n'
                '        from\n'
                '        createdAt\n'
                '        currentState\n'
                '        HumanID\n'
                '        currentStateID\n'
                '        severity\n'
                '        priority\n'
                '        location\n'
                '        channelId\n'
                '        updatedAt\n'
                '        resolvedTime\n'
                '        resolvedComment\n'
                '        Symptoms\n'
                '        meetingType\n'
                '        meetingId\n'
                '      }\n'
                '    }\n'
                '  }\n',
 'oncreateprivatekey': '\n'
                       '  subscription OnCreatePrivateKey {\n'
                       '    onCreatePrivateKey {\n'
                       '      id\n'
                       '      sshKey\n'
                       '      userName\n'
                       '      createdAt\n'
                       '      updatedAt\n'
                       '    }\n'
                       '  }\n',
 'oncreateremotecontrol': '\n'
                          '  subscription OnCreateRemoteControl {\n'
                          '    onCreateRemoteControl {\n'
                          '      id\n'
                          '      from\n'
                          '      to\n'
                          '      command\n'
                          '      createdAt\n'
                          '      updatedAt\n'
                          '    }\n'
                          '  }\n',
 'oncreatereportsummaryeditor': '\n'
                                '  subscription OnCreateReportSummaryEditor {\n'
                                '    onCreateReportSummaryEditor {\n'
                                '      id\n'
                                '      investigationId\n'
                                '      createdAt\n'
                                '      updatedAt\n'
                                '      author\n'
                                '      content\n'
                                '      type\n'
                                '    }\n'
                                '  }\n',
 'oncreaterunbookconnectorformlink': '\n'
                                     '  subscription '
                                     'OnCreateRunbookConnectorFormLink {\n'
                                     '    onCreateRunbookConnectorFormLink {\n'
                                     '      id\n'
                                     '      connectorFormId\n'
                                     '      runbookId\n'
                                     '      connectorForm {\n'
                                     '        id\n'
                                     '        createdAt\n'
                                     '        updatedAt\n'
                                     '        name\n'
                                     '        owner\n'
                                     '        connectorID\n'
                                     '        configData\n'
                                     '        commandData\n'
                                     '        nodeData\n'
                                     '        scope\n'
                                     '        PeopleCanView\n'
                                     '        PeopleCanAccess\n'
                                     '        GroupsCanView\n'
                                     '        GroupsCanAccess\n'
                                     '      }\n'
                                     '      runbook {\n'
                                     '        id\n'
                                     '        name\n'
                                     '        description\n'
                                     '        content\n'
                                     '        author\n'
                                     '        commands\n'
                                     '        createdAt\n'
                                     '        updatedAt\n'
                                     '        RunBookConnectors\n'
                                     '        type\n'
                                     '        longSave\n'
                                     '        rbVars\n'
                                     '        scope\n'
                                     '        PeopleCanView\n'
                                     '        PeopleCanAccess\n'
                                     '        GroupsCanView\n'
                                     '        GroupsCanAccess\n'
                                     '      }\n'
                                     '    }\n'
                                     '  }\n',
 'oncreateschedpbs': '\n'
                     '  subscription OnCreateSchedPBs {\n'
                     '    onCreateSchedPBs {\n'
                     '      id\n'
                     '      pbId\n'
                     '      frequency\n'
                     '      pbName\n'
                     '      rbVars\n'
                     '      scheduled\n'
                     '      createdAt\n'
                     '      updatedAt\n'
                     '      author\n'
                     '    }\n'
                     '  }\n',
 'oncreatesshtabs': '\n'
                    '  subscription OnCreateSshTabs {\n'
                    '    onCreateSshTabs {\n'
                    '      id\n'
                    '      investigationId\n'
                    '      host\n'
                    '      author\n'
                    '      userName\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '    }\n'
                    '  }\n',
 'oncreatestash': '\n'
                  '  subscription OnCreateStash {\n'
                  '    onCreateStash {\n'
                  '      id\n'
                  '      Key\n'
                  '      Value\n'
                  '      createdAt\n'
                  '      updatedAt\n'
                  '      author\n'
                  '      scope\n'
                  '      PeopleCanView\n'
                  '      PeopleCanAccess\n'
                  '      GroupsCanView\n'
                  '      GroupsCanAccess\n'
                  '    }\n'
                  '  }\n',
 'oncreatestate': '\n'
                  '  subscription OnCreateState {\n'
                  '    onCreateState {\n'
                  '      id\n'
                  '      name\n'
                  '      createdAt\n'
                  '      updatedAt\n'
                  '      author\n'
                  '      lastState\n'
                  '      investigationId\n'
                  '      investigation {\n'
                  '        id\n'
                  '        title\n'
                  '        from\n'
                  '        createdAt\n'
                  '        currentState\n'
                  '        HumanID\n'
                  '        currentStateID\n'
                  '        severity\n'
                  '        priority\n'
                  '        location\n'
                  '        channelId\n'
                  '        updatedAt\n'
                  '        resolvedTime\n'
                  '        resolvedComment\n'
                  '        Symptoms\n'
                  '        meetingType\n'
                  '        meetingId\n'
                  '      }\n'
                  '    }\n'
                  '  }\n',
 'oncreatesummaryinvestigation': '\n'
                                 '  subscription '
                                 'OnCreateSummaryInvestigation($owner: String) '
                                 '{\n'
                                 '    onCreateSummaryInvestigation(owner: '
                                 '$owner) {\n'
                                 '      id\n'
                                 '      createdAt\n'
                                 '      updatedAt\n'
                                 '      resolvedTime\n'
                                 '      OriginalID\n'
                                 '      title\n'
                                 '      HumanID\n'
                                 '      Commands\n'
                                 '      InvestigationEvents\n'
                                 '      CompleteInvestigationEvents\n'
                                 '      Participants\n'
                                 '      Comments\n'
                                 '      Pins\n'
                                 '      AvailableRunbooks\n'
                                 '      UsedRunbooks\n'
                                 '      Hints\n'
                                 '      Symptoms\n'
                                 '      owner\n'
                                 '    }\n'
                                 '  }\n',
 'oncreatetenantcustomer': '\n'
                           '  subscription OnCreateTenantCustomer {\n'
                           '    onCreateTenantCustomer {\n'
                           '      label\n'
                           '      impactLabels\n'
                           '      createdAt\n'
                           '      updatedAt\n'
                           '      customerName\n'
                           '      email\n'
                           '      phoneno\n'
                           '      SLAType\n'
                           '      city\n'
                           '      state\n'
                           '      contry\n'
                           '      zipcode\n'
                           '    }\n'
                           '  }\n',
 'oncreatetranscriptionrecords': '\n'
                                 '  subscription OnCreateTranscriptionRecords '
                                 '{\n'
                                 '    onCreateTranscriptionRecords {\n'
                                 '      id\n'
                                 '      investigationId\n'
                                 '      createdAt\n'
                                 '      updatedAt\n'
                                 '      spokenBy\n'
                                 '      content\n'
                                 '    }\n'
                                 '  }\n',
 'oncreateusedtogenhintalready': '\n'
                                 '  subscription OnCreateUsedToGenHintAlready '
                                 '{\n'
                                 '    onCreateUsedToGenHintAlready {\n'
                                 '      id\n'
                                 '      createdAt\n'
                                 '      updatedAt\n'
                                 '      investigationId\n'
                                 '      commands\n'
                                 '      text\n'
                                 '      investigation {\n'
                                 '        id\n'
                                 '        title\n'
                                 '        from\n'
                                 '        createdAt\n'
                                 '        currentState\n'
                                 '        HumanID\n'
                                 '        currentStateID\n'
                                 '        severity\n'
                                 '        priority\n'
                                 '        location\n'
                                 '        channelId\n'
                                 '        updatedAt\n'
                                 '        resolvedTime\n'
                                 '        resolvedComment\n'
                                 '        Symptoms\n'
                                 '        meetingType\n'
                                 '        meetingId\n'
                                 '      }\n'
                                 '    }\n'
                                 '  }\n',
 'oncreateuser': '\n'
                 '  subscription OnCreateUser($owner: String) {\n'
                 '    onCreateUser(owner: $owner) {\n'
                 '      id\n'
                 '      username\n'
                 '      email\n'
                 '      firstname\n'
                 '      lastname\n'
                 '      avatar\n'
                 '      mood\n'
                 '      name\n'
                 '      role\n'
                 '      status\n'
                 '      timezone\n'
                 '      phone\n'
                 '      address\n'
                 '      location\n'
                 '      chatList {\n'
                 '        nextToken\n'
                 '      }\n'
                 '      messages {\n'
                 '        nextToken\n'
                 '      }\n'
                 '      createdAt\n'
                 '      updatedAt\n'
                 '      owner\n'
                 '    }\n'
                 '  }\n',
 'oncreateuseractivity': '\n'
                         '  subscription OnCreateUserActivity {\n'
                         '    onCreateUserActivity {\n'
                         '      id\n'
                         '      userID\n'
                         '      status\n'
                         '      investigationID\n'
                         '      createdAt\n'
                         '      updatedAt\n'
                         '      investigation {\n'
                         '        id\n'
                         '        title\n'
                         '        from\n'
                         '        createdAt\n'
                         '        currentState\n'
                         '        HumanID\n'
                         '        currentStateID\n'
                         '        severity\n'
                         '        priority\n'
                         '        location\n'
                         '        channelId\n'
                         '        updatedAt\n'
                         '        resolvedTime\n'
                         '        resolvedComment\n'
                         '        Symptoms\n'
                         '        meetingType\n'
                         '        meetingId\n'
                         '      }\n'
                         '      user {\n'
                         '        id\n'
                         '        username\n'
                         '        email\n'
                         '        firstname\n'
                         '        lastname\n'
                         '        avatar\n'
                         '        mood\n'
                         '        name\n'
                         '        role\n'
                         '        status\n'
                         '        timezone\n'
                         '        phone\n'
                         '        address\n'
                         '        location\n'
                         '        createdAt\n'
                         '        updatedAt\n'
                         '        owner\n'
                         '      }\n'
                         '    }\n'
                         '  }\n',
 'oncreateusersettinglabellink': '\n'
                                 '  subscription OnCreateUserSettingLabelLink '
                                 '{\n'
                                 '    onCreateUserSettingLabelLink {\n'
                                 '      id\n'
                                 '      userSettingId\n'
                                 '      userSetting {\n'
                                 '        id\n'
                                 '        userId\n'
                                 '        owner\n'
                                 '        createdAt\n'
                                 '        updatedAt\n'
                                 '        value\n'
                                 '        url\n'
                                 '        name\n'
                                 '        type\n'
                                 '        showWelcomeNext\n'
                                 '        showWelcomeSkip\n'
                                 '        showWelcomeRemind\n'
                                 '        welcomeData\n'
                                 '      }\n'
                                 '      labelID\n'
                                 '      label {\n'
                                 '        id\n'
                                 '        name\n'
                                 '        color\n'
                                 '        type\n'
                                 '      }\n'
                                 '      type\n'
                                 '    }\n'
                                 '  }\n',
 'ondeletealertapikey': '\n'
                        '  subscription OnDeleteAlertApiKey {\n'
                        '    onDeleteAlertApiKey {\n'
                        '      id\n'
                        '      alertsPbName\n'
                        '      createdAt\n'
                        '      updatedAt\n'
                        '      author\n'
                        '    }\n'
                        '  }\n',
 'ondeleteallrunbooks': '\n'
                        '  subscription OnDeleteAllRunbooks {\n'
                        '    onDeleteAllRunbooks {\n'
                        '      id\n'
                        '      name\n'
                        '      description\n'
                        '      content\n'
                        '      author\n'
                        '      commands\n'
                        '      createdAt\n'
                        '      updatedAt\n'
                        '      RunBookConnectors\n'
                        '      type\n'
                        '      longSave\n'
                        '      rbVars\n'
                        '      scope\n'
                        '      PeopleCanView\n'
                        '      PeopleCanAccess\n'
                        '      GroupsCanView\n'
                        '      GroupsCanAccess\n'
                        '      connectorForms {\n'
                        '        nextToken\n'
                        '      }\n'
                        '    }\n'
                        '  }\n',
 'ondeleteallworkflows': '\n'
                         '  subscription OnDeleteAllWorkflows {\n'
                         '    onDeleteAllWorkflows {\n'
                         '      id\n'
                         '      createdAt\n'
                         '      updatedAt\n'
                         '      name\n'
                         '      description\n'
                         '      type\n'
                         '      author\n'
                         '      longSave\n'
                         '      rbVars\n'
                         '    }\n'
                         '  }\n',
 'ondeletebase64image': '\n'
                        '  subscription OnDeleteBase64Image {\n'
                        '    onDeleteBase64Image {\n'
                        '      id\n'
                        '      playbookID\n'
                        '      base64String\n'
                        '    }\n'
                        '  }\n',
 'ondeletechannel': '\n'
                    '  subscription OnDeleteChannel {\n'
                    '    onDeleteChannel {\n'
                    '      id\n'
                    '      messages {\n'
                    '        nextToken\n'
                    '      }\n'
                    '      associated {\n'
                    '        nextToken\n'
                    '      }\n'
                    '      name\n'
                    '      title\n'
                    '      members\n'
                    '      membersState\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '      memberLocation\n'
                    '    }\n'
                    '  }\n',
 'ondeletechat': '\n'
                 '  subscription OnDeleteChat {\n'
                 '    onDeleteChat {\n'
                 '      id\n'
                 '      from\n'
                 '      content\n'
                 '      createdAt\n'
                 '    }\n'
                 '  }\n',
 'ondeletecheatsheet': '\n'
                       '  subscription OnDeleteCheatSheet {\n'
                       '    onDeleteCheatSheet {\n'
                       '      id\n'
                       '      createdAt\n'
                       '      updatedAt\n'
                       '      title\n'
                       '      author\n'
                       '      content\n'
                       '      type\n'
                       '    }\n'
                       '  }\n',
 'ondeletechecklist': '\n'
                      '  subscription OnDeleteCheckList {\n'
                      '    onDeleteCheckList {\n'
                      '      id\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '      name\n'
                      '      description\n'
                      '      type\n'
                      '      content\n'
                      '      author\n'
                      '      CheckListLink {\n'
                      '        nextToken\n'
                      '      }\n'
                      '      CheckListInvLink {\n'
                      '        nextToken\n'
                      '      }\n'
                      '    }\n'
                      '  }\n',
 'ondeletechecklistinvlink': '\n'
                             '  subscription OnDeleteCheckListInvLink($owner: '
                             'String) {\n'
                             '    onDeleteCheckListInvLink(owner: $owner) {\n'
                             '      id\n'
                             '      createdAt\n'
                             '      updatedAt\n'
                             '      investigationID\n'
                             '      CheckListID\n'
                             '      CheckList {\n'
                             '        id\n'
                             '        createdAt\n'
                             '        updatedAt\n'
                             '        name\n'
                             '        description\n'
                             '        type\n'
                             '        content\n'
                             '        author\n'
                             '      }\n'
                             '      investigation {\n'
                             '        id\n'
                             '        title\n'
                             '        from\n'
                             '        createdAt\n'
                             '        currentState\n'
                             '        HumanID\n'
                             '        currentStateID\n'
                             '        severity\n'
                             '        priority\n'
                             '        location\n'
                             '        channelId\n'
                             '        updatedAt\n'
                             '        resolvedTime\n'
                             '        resolvedComment\n'
                             '        Symptoms\n'
                             '        meetingType\n'
                             '        meetingId\n'
                             '      }\n'
                             '      owner\n'
                             '    }\n'
                             '  }\n',
 'ondeletechecklistitem': '\n'
                          '  subscription OnDeleteCheckListItem {\n'
                          '    onDeleteCheckListItem {\n'
                          '      id\n'
                          '      localID\n'
                          '      createdAt\n'
                          '      updatedAt\n'
                          '      author\n'
                          '      content\n'
                          '      title\n'
                          '      type\n'
                          '      connection\n'
                          '      MMNodeConnection\n'
                          '      investigationID\n'
                          '      assignee\n'
                          '      associatedPlaybooks\n'
                          '      associatedCommands\n'
                          '      CheckListLink {\n'
                          '        nextToken\n'
                          '      }\n'
                          '    }\n'
                          '  }\n',
 'ondeleteclick': '\n'
                  '  subscription OnDeleteClick {\n'
                  '    onDeleteClick {\n'
                  '      id\n'
                  '      count\n'
                  '      type\n'
                  '      featureName\n'
                  '      createdAt\n'
                  '      updatedAt\n'
                  '      readAt\n'
                  '    }\n'
                  '  }\n',
 'ondeleteclicllink': '\n'
                      '  subscription OnDeleteCliclLink($author: String) {\n'
                      '    onDeleteCLICLLink(author: $author) {\n'
                      '      id\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '      CheckListItemID\n'
                      '      lane\n'
                      '      CheckListID\n'
                      '      CheckList {\n'
                      '        id\n'
                      '        createdAt\n'
                      '        updatedAt\n'
                      '        name\n'
                      '        description\n'
                      '        type\n'
                      '        content\n'
                      '        author\n'
                      '      }\n'
                      '      CheckListItem {\n'
                      '        id\n'
                      '        localID\n'
                      '        createdAt\n'
                      '        updatedAt\n'
                      '        author\n'
                      '        content\n'
                      '        title\n'
                      '        type\n'
                      '        connection\n'
                      '        MMNodeConnection\n'
                      '        investigationID\n'
                      '        assignee\n'
                      '        associatedPlaybooks\n'
                      '        associatedCommands\n'
                      '      }\n'
                      '    }\n'
                      '  }\n',
 'ondeletecommands': '\n'
                     '  subscription OnDeleteCommands {\n'
                     '    onDeleteCommands {\n'
                     '      id\n'
                     '      from\n'
                     '      mode\n'
                     '      command\n'
                     '      output\n'
                     '      state\n'
                     '      returnCode\n'
                     '      investigationId\n'
                     '      createdAt\n'
                     '      updatedAt\n'
                     '      investigation {\n'
                     '        id\n'
                     '        title\n'
                     '        from\n'
                     '        createdAt\n'
                     '        currentState\n'
                     '        HumanID\n'
                     '        currentStateID\n'
                     '        severity\n'
                     '        priority\n'
                     '        location\n'
                     '        channelId\n'
                     '        updatedAt\n'
                     '        resolvedTime\n'
                     '        resolvedComment\n'
                     '        Symptoms\n'
                     '        meetingType\n'
                     '        meetingId\n'
                     '      }\n'
                     '    }\n'
                     '  }\n',
 'ondeletecomment': '\n'
                    '  subscription OnDeleteComment {\n'
                    '    onDeleteComment {\n'
                    '      id\n'
                    '      parent\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '      author\n'
                    '      content\n'
                    '      type\n'
                    '      links\n'
                    '      investigationId\n'
                    '      investigation {\n'
                    '        id\n'
                    '        title\n'
                    '        from\n'
                    '        createdAt\n'
                    '        currentState\n'
                    '        HumanID\n'
                    '        currentStateID\n'
                    '        severity\n'
                    '        priority\n'
                    '        location\n'
                    '        channelId\n'
                    '        updatedAt\n'
                    '        resolvedTime\n'
                    '        resolvedComment\n'
                    '        Symptoms\n'
                    '        meetingType\n'
                    '        meetingId\n'
                    '      }\n'
                    '    }\n'
                    '  }\n',
 'ondeleteconferenceconfig': '\n'
                             '  subscription OnDeleteConferenceConfig {\n'
                             '    onDeleteConferenceConfig {\n'
                             '      id\n'
                             '      url\n'
                             '      userName\n'
                             '      password\n'
                             '      author\n'
                             '      createdAt\n'
                             '      updatedAt\n'
                             '    }\n'
                             '  }\n',
 'ondeleteconnectorform': '\n'
                          '  subscription OnDeleteConnectorForm {\n'
                          '    onDeleteConnectorForm {\n'
                          '      id\n'
                          '      createdAt\n'
                          '      updatedAt\n'
                          '      name\n'
                          '      owner\n'
                          '      connectorID\n'
                          '      connector {\n'
                          '        id\n'
                          '        createdAt\n'
                          '        updatedAt\n'
                          '        category\n'
                          '        name\n'
                          '        owner\n'
                          '        description\n'
                          '        detaileddescription\n'
                          '        iconPath\n'
                          '        version\n'
                          '        md5\n'
                          '        source\n'
                          '        configuration\n'
                          '        commands\n'
                          '        commandsType\n'
                          '        script\n'
                          '        scriptType\n'
                          '        scriptPath\n'
                          '        scope\n'
                          '        PeopleCanView\n'
                          '        PeopleCanAccess\n'
                          '        GroupsCanView\n'
                          '        GroupsCanAccess\n'
                          '      }\n'
                          '      configData\n'
                          '      commandData\n'
                          '      nodeData\n'
                          '      scope\n'
                          '      PeopleCanView\n'
                          '      PeopleCanAccess\n'
                          '      GroupsCanView\n'
                          '      GroupsCanAccess\n'
                          '      runbooks {\n'
                          '        nextToken\n'
                          '      }\n'
                          '    }\n'
                          '  }\n',
 'ondeleteconnectors': '\n'
                       '  subscription OnDeleteConnectors {\n'
                       '    onDeleteConnectors {\n'
                       '      id\n'
                       '      createdAt\n'
                       '      updatedAt\n'
                       '      category\n'
                       '      name\n'
                       '      owner\n'
                       '      description\n'
                       '      detaileddescription\n'
                       '      iconPath\n'
                       '      version\n'
                       '      md5\n'
                       '      source\n'
                       '      configuration\n'
                       '      commands\n'
                       '      commandsType\n'
                       '      script\n'
                       '      scriptType\n'
                       '      scriptPath\n'
                       '      scope\n'
                       '      PeopleCanView\n'
                       '      PeopleCanAccess\n'
                       '      GroupsCanView\n'
                       '      GroupsCanAccess\n'
                       '    }\n'
                       '  }\n',
 'ondeletedashboardconfig': '\n'
                            '  subscription OnDeleteDashboardConfig {\n'
                            '    onDeleteDashboardConfig {\n'
                            '      id\n'
                            '      url\n'
                            '      labels {\n'
                            '        nextToken\n'
                            '      }\n'
                            '      author\n'
                            '      createdAt\n'
                            '      updatedAt\n'
                            '    }\n'
                            '  }\n',
 'ondeleteecubesandboxexecution': '\n'
                                  '  subscription '
                                  'OnDeleteEcubeSandboxExecution {\n'
                                  '    onDeleteEcubeSandboxExecution {\n'
                                  '      id\n'
                                  '      owner\n'
                                  '      output\n'
                                  '      outputType\n'
                                  '      returnCode\n'
                                  '      status\n'
                                  '      createdAt\n'
                                  '      updatedAt\n'
                                  '      E3One\n'
                                  '      E3Two\n'
                                  '      E3Three\n'
                                  '    }\n'
                                  '  }\n',
 'ondeleteepicautocomplete': '\n'
                             '  subscription OnDeleteEpicAutoComplete($author: '
                             'String) {\n'
                             '    onDeleteEpicAutoComplete(author: $author) {\n'
                             '      id\n'
                             '      author\n'
                             '      cliCommand\n'
                             '      command\n'
                             '      createdAt\n'
                             '      updatedAt\n'
                             '      investigationId\n'
                             '      times\n'
                             '    }\n'
                             '  }\n',
 'ondeleteepiclicommand': '\n'
                          '  subscription OnDeleteEpicliCommand {\n'
                          '    onDeleteEPICLICommand {\n'
                          '      id\n'
                          '      createdAt\n'
                          '      updatedAt\n'
                          '      author\n'
                          '      content\n'
                          '      type\n'
                          '    }\n'
                          '  }\n',
 'ondeleteexecutedrunbooks': '\n'
                             '  subscription OnDeleteExecutedRunbooks {\n'
                             '    onDeleteExecutedRunbooks {\n'
                             '      id\n'
                             '      createdAt\n'
                             '      updatedAt\n'
                             '      runbookID\n'
                             '      investigationId\n'
                             '      output\n'
                             '      outputType\n'
                             '      title\n'
                             '      state\n'
                             '      author\n'
                             '      rbVars\n'
                             '      callbackUrl\n'
                             '      callbackData\n'
                             '      source\n'
                             '      investigation {\n'
                             '        id\n'
                             '        title\n'
                             '        from\n'
                             '        createdAt\n'
                             '        currentState\n'
                             '        HumanID\n'
                             '        currentStateID\n'
                             '        severity\n'
                             '        priority\n'
                             '        location\n'
                             '        channelId\n'
                             '        updatedAt\n'
                             '        resolvedTime\n'
                             '        resolvedComment\n'
                             '        Symptoms\n'
                             '        meetingType\n'
                             '        meetingId\n'
                             '      }\n'
                             '      runbook {\n'
                             '        id\n'
                             '        name\n'
                             '        description\n'
                             '        content\n'
                             '        author\n'
                             '        commands\n'
                             '        createdAt\n'
                             '        updatedAt\n'
                             '        RunBookConnectors\n'
                             '        type\n'
                             '        longSave\n'
                             '        rbVars\n'
                             '        scope\n'
                             '        PeopleCanView\n'
                             '        PeopleCanAccess\n'
                             '        GroupsCanView\n'
                             '        GroupsCanAccess\n'
                             '      }\n'
                             '    }\n'
                             '  }\n',
 'ondeleteexecutedworkflowstate': '\n'
                                  '  subscription '
                                  'OnDeleteExecutedWorkflowState {\n'
                                  '    onDeleteExecutedWorkflowState {\n'
                                  '      id\n'
                                  '      createdAt\n'
                                  '      updatedAt\n'
                                  '      name\n'
                                  '      state\n'
                                  '      output\n'
                                  '      type\n'
                                  '      allworkflowID\n'
                                  '      investigationID\n'
                                  '      investigation {\n'
                                  '        id\n'
                                  '        title\n'
                                  '        from\n'
                                  '        createdAt\n'
                                  '        currentState\n'
                                  '        HumanID\n'
                                  '        currentStateID\n'
                                  '        severity\n'
                                  '        priority\n'
                                  '        location\n'
                                  '        channelId\n'
                                  '        updatedAt\n'
                                  '        resolvedTime\n'
                                  '        resolvedComment\n'
                                  '        Symptoms\n'
                                  '        meetingType\n'
                                  '        meetingId\n'
                                  '      }\n'
                                  '    }\n'
                                  '  }\n',
 'ondeletegroupmember': '\n'
                        '  subscription OnDeleteGroupMember {\n'
                        '    onDeleteGroupMember {\n'
                        '      id\n'
                        '      hostId\n'
                        '      groupId\n'
                        '      host {\n'
                        '        id\n'
                        '        inventoryId\n'
                        '        createdAt\n'
                        '        updatedAt\n'
                        '        author\n'
                        '        host\n'
                        '        port\n'
                        '        vars\n'
                        '      }\n'
                        '      group {\n'
                        '        id\n'
                        '        inventoryId\n'
                        '        createdAt\n'
                        '        updatedAt\n'
                        '        author\n'
                        '        name\n'
                        '        groups\n'
                        '        port\n'
                        '        vars\n'
                        '      }\n'
                        '    }\n'
                        '  }\n',
 'ondeleteguardrail': '\n'
                      '  subscription OnDeleteGuardRail {\n'
                      '    onDeleteGuardRail {\n'
                      '      id\n'
                      '      timeOut\n'
                      '      message\n'
                      '      labels {\n'
                      '        nextToken\n'
                      '      }\n'
                      '      author\n'
                      '      active\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '    }\n'
                      '  }\n',
 'ondeletehint': '\n'
                 '  subscription OnDeleteHint {\n'
                 '    onDeleteHint {\n'
                 '      id\n'
                 '      investigationId\n'
                 '      createdAt\n'
                 '      updatedAt\n'
                 '      type\n'
                 '      connection\n'
                 '      pastInvestigationID\n'
                 '      title\n'
                 '      importance\n'
                 '      starrted\n'
                 '      applied\n'
                 '      url\n'
                 '      why\n'
                 '    }\n'
                 '  }\n',
 'ondeleteinventory': '\n'
                      '  subscription OnDeleteInventory {\n'
                      '    onDeleteInventory {\n'
                      '      id\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '      author\n'
                      '      name\n'
                      '      all {\n'
                      '        nextToken\n'
                      '      }\n'
                      '      groups {\n'
                      '        nextToken\n'
                      '      }\n'
                      '      vars\n'
                      '    }\n'
                      '  }\n',
 'ondeleteinventorygroup': '\n'
                           '  subscription OnDeleteInventoryGroup {\n'
                           '    onDeleteInventoryGroup {\n'
                           '      id\n'
                           '      inventoryId\n'
                           '      createdAt\n'
                           '      updatedAt\n'
                           '      author\n'
                           '      name\n'
                           '      hosts {\n'
                           '        nextToken\n'
                           '      }\n'
                           '      groups\n'
                           '      port\n'
                           '      vars\n'
                           '      inventory {\n'
                           '        id\n'
                           '        createdAt\n'
                           '        updatedAt\n'
                           '        author\n'
                           '        name\n'
                           '        vars\n'
                           '      }\n'
                           '    }\n'
                           '  }\n',
 'ondeleteinventoryhost': '\n'
                          '  subscription OnDeleteInventoryHost {\n'
                          '    onDeleteInventoryHost {\n'
                          '      id\n'
                          '      inventoryId\n'
                          '      createdAt\n'
                          '      updatedAt\n'
                          '      author\n'
                          '      host\n'
                          '      port\n'
                          '      vars\n'
                          '      groups {\n'
                          '        nextToken\n'
                          '      }\n'
                          '      inventory {\n'
                          '        id\n'
                          '        createdAt\n'
                          '        updatedAt\n'
                          '        author\n'
                          '        name\n'
                          '        vars\n'
                          '      }\n'
                          '    }\n'
                          '  }\n',
 'ondeleteinvestigation': '\n'
                          '  subscription OnDeleteInvestigation {\n'
                          '    onDeleteInvestigation {\n'
                          '      id\n'
                          '      title\n'
                          '      from\n'
                          '      createdAt\n'
                          '      currentState\n'
                          '      HumanID\n'
                          '      currentStateID\n'
                          '      severity\n'
                          '      priority\n'
                          '      location\n'
                          '      labels {\n'
                          '        nextToken\n'
                          '      }\n'
                          '      channelId\n'
                          '      investigationChannel {\n'
                          '        id\n'
                          '        name\n'
                          '        title\n'
                          '        members\n'
                          '        membersState\n'
                          '        createdAt\n'
                          '        updatedAt\n'
                          '        memberLocation\n'
                          '      }\n'
                          '      updatedAt\n'
                          '      resolvedTime\n'
                          '      resolvedComment\n'
                          '      Symptoms\n'
                          '      MMNodeLinks {\n'
                          '        nextToken\n'
                          '      }\n'
                          '      CheckListInvLink {\n'
                          '        nextToken\n'
                          '      }\n'
                          '      meetingType\n'
                          '      meetingId\n'
                          '    }\n'
                          '  }\n',
 'ondeleteinvestigationevent': '\n'
                               '  subscription OnDeleteInvestigationEvent {\n'
                               '    onDeleteInvestigationEvent {\n'
                               '      id\n'
                               '      createdAt\n'
                               '      updatedAt\n'
                               '      author\n'
                               '      content\n'
                               '      type\n'
                               '      links\n'
                               '      investigationId\n'
                               '      investigation {\n'
                               '        id\n'
                               '        title\n'
                               '        from\n'
                               '        createdAt\n'
                               '        currentState\n'
                               '        HumanID\n'
                               '        currentStateID\n'
                               '        severity\n'
                               '        priority\n'
                               '        location\n'
                               '        channelId\n'
                               '        updatedAt\n'
                               '        resolvedTime\n'
                               '        resolvedComment\n'
                               '        Symptoms\n'
                               '        meetingType\n'
                               '        meetingId\n'
                               '      }\n'
                               '    }\n'
                               '  }\n',
 'ondeleteinvestigationguestuserlink': '\n'
                                       '  subscription '
                                       'OnDeleteInvestigationGuestUserLink {\n'
                                       '    onDeleteInvestigationGuestUserLink '
                                       '{\n'
                                       '      id\n'
                                       '      userName\n'
                                       '      createdAt\n'
                                       '      updatedAt\n'
                                       '      investigationID\n'
                                       '      channelID\n'
                                       '    }\n'
                                       '  }\n',
 'ondeletelabel': '\n'
                  '  subscription OnDeleteLabel {\n'
                  '    onDeleteLabel {\n'
                  '      id\n'
                  '      name\n'
                  '      color\n'
                  '      type\n'
                  '      investigations {\n'
                  '        nextToken\n'
                  '      }\n'
                  '      userSettings {\n'
                  '        nextToken\n'
                  '      }\n'
                  '    }\n'
                  '  }\n',
 'ondeleteleadboard': '\n'
                      '  subscription OnDeleteLeadBoard {\n'
                      '    onDeleteLeadBoard {\n'
                      '      id\n'
                      '      investigationId\n'
                      '      content\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '      investigation {\n'
                      '        id\n'
                      '        title\n'
                      '        from\n'
                      '        createdAt\n'
                      '        currentState\n'
                      '        HumanID\n'
                      '        currentStateID\n'
                      '        severity\n'
                      '        priority\n'
                      '        location\n'
                      '        channelId\n'
                      '        updatedAt\n'
                      '        resolvedTime\n'
                      '        resolvedComment\n'
                      '        Symptoms\n'
                      '        meetingType\n'
                      '        meetingId\n'
                      '      }\n'
                      '    }\n'
                      '  }\n',
 'ondeleteleadboardnode': '\n'
                          '  subscription OnDeleteLeadBoardNode {\n'
                          '    onDeleteLeadBoardNode {\n'
                          '      id\n'
                          '      localID\n'
                          '      createdAt\n'
                          '      updatedAt\n'
                          '      author\n'
                          '      content\n'
                          '      title\n'
                          '      notes\n'
                          '      associatedPlaybooks\n'
                          '      associatedCommands\n'
                          '      InvestLinks {\n'
                          '        nextToken\n'
                          '      }\n'
                          '    }\n'
                          '  }\n',
 'ondeletemessage': '\n'
                    '  subscription OnDeleteMessage {\n'
                    '    onDeleteMessage {\n'
                    '      id\n'
                    '      authorId\n'
                    '      content\n'
                    '      type\n'
                    '      channel {\n'
                    '        id\n'
                    '        name\n'
                    '        title\n'
                    '        members\n'
                    '        membersState\n'
                    '        createdAt\n'
                    '        updatedAt\n'
                    '        memberLocation\n'
                    '      }\n'
                    '      messageChannelId\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '      author {\n'
                    '        id\n'
                    '        username\n'
                    '        email\n'
                    '        firstname\n'
                    '        lastname\n'
                    '        avatar\n'
                    '        mood\n'
                    '        name\n'
                    '        role\n'
                    '        status\n'
                    '        timezone\n'
                    '        phone\n'
                    '        address\n'
                    '        location\n'
                    '        createdAt\n'
                    '        updatedAt\n'
                    '        owner\n'
                    '      }\n'
                    '    }\n'
                    '  }\n',
 'ondeletemmnodelink': '\n'
                       '  subscription OnDeleteMmNodeLink {\n'
                       '    onDeleteMMNodeLink {\n'
                       '      id\n'
                       '      createdAt\n'
                       '      updatedAt\n'
                       '      assigned\n'
                       '      state\n'
                       '      content\n'
                       '      author\n'
                       '      investigationID\n'
                       '      connectionToTask\n'
                       '      LBNID\n'
                       '      LeadBoardNodeId {\n'
                       '        id\n'
                       '        localID\n'
                       '        createdAt\n'
                       '        updatedAt\n'
                       '        author\n'
                       '        content\n'
                       '        title\n'
                       '        notes\n'
                       '        associatedPlaybooks\n'
                       '        associatedCommands\n'
                       '      }\n'
                       '      investigationId {\n'
                       '        id\n'
                       '        title\n'
                       '        from\n'
                       '        createdAt\n'
                       '        currentState\n'
                       '        HumanID\n'
                       '        currentStateID\n'
                       '        severity\n'
                       '        priority\n'
                       '        location\n'
                       '        channelId\n'
                       '        updatedAt\n'
                       '        resolvedTime\n'
                       '        resolvedComment\n'
                       '        Symptoms\n'
                       '        meetingType\n'
                       '        meetingId\n'
                       '      }\n'
                       '    }\n'
                       '  }\n',
 'ondeletenotification': '\n'
                         '  subscription OnDeleteNotification {\n'
                         '    onDeleteNotification {\n'
                         '      id\n'
                         '      userName\n'
                         '      content\n'
                         '      containerType\n'
                         '      containerId\n'
                         '      investigationId\n'
                         '      isViewed\n'
                         '      createdAt\n'
                         '      updatedAt\n'
                         '    }\n'
                         '  }\n',
 'ondeletepin': '\n'
                '  subscription OnDeletePin {\n'
                '    onDeletePin {\n'
                '      id\n'
                '      imageId\n'
                '      content\n'
                '      createdAt\n'
                '      updatedAt\n'
                '      author\n'
                '      investigationId\n'
                '      investigation {\n'
                '        id\n'
                '        title\n'
                '        from\n'
                '        createdAt\n'
                '        currentState\n'
                '        HumanID\n'
                '        currentStateID\n'
                '        severity\n'
                '        priority\n'
                '        location\n'
                '        channelId\n'
                '        updatedAt\n'
                '        resolvedTime\n'
                '        resolvedComment\n'
                '        Symptoms\n'
                '        meetingType\n'
                '        meetingId\n'
                '      }\n'
                '    }\n'
                '  }\n',
 'ondeleteprivatekey': '\n'
                       '  subscription OnDeletePrivateKey {\n'
                       '    onDeletePrivateKey {\n'
                       '      id\n'
                       '      sshKey\n'
                       '      userName\n'
                       '      createdAt\n'
                       '      updatedAt\n'
                       '    }\n'
                       '  }\n',
 'ondeleteremotecontrol': '\n'
                          '  subscription OnDeleteRemoteControl {\n'
                          '    onDeleteRemoteControl {\n'
                          '      id\n'
                          '      from\n'
                          '      to\n'
                          '      command\n'
                          '      createdAt\n'
                          '      updatedAt\n'
                          '    }\n'
                          '  }\n',
 'ondeletereportsummaryeditor': '\n'
                                '  subscription OnDeleteReportSummaryEditor {\n'
                                '    onDeleteReportSummaryEditor {\n'
                                '      id\n'
                                '      investigationId\n'
                                '      createdAt\n'
                                '      updatedAt\n'
                                '      author\n'
                                '      content\n'
                                '      type\n'
                                '    }\n'
                                '  }\n',
 'ondeleterunbookconnectorformlink': '\n'
                                     '  subscription '
                                     'OnDeleteRunbookConnectorFormLink {\n'
                                     '    onDeleteRunbookConnectorFormLink {\n'
                                     '      id\n'
                                     '      connectorFormId\n'
                                     '      runbookId\n'
                                     '      connectorForm {\n'
                                     '        id\n'
                                     '        createdAt\n'
                                     '        updatedAt\n'
                                     '        name\n'
                                     '        owner\n'
                                     '        connectorID\n'
                                     '        configData\n'
                                     '        commandData\n'
                                     '        nodeData\n'
                                     '        scope\n'
                                     '        PeopleCanView\n'
                                     '        PeopleCanAccess\n'
                                     '        GroupsCanView\n'
                                     '        GroupsCanAccess\n'
                                     '      }\n'
                                     '      runbook {\n'
                                     '        id\n'
                                     '        name\n'
                                     '        description\n'
                                     '        content\n'
                                     '        author\n'
                                     '        commands\n'
                                     '        createdAt\n'
                                     '        updatedAt\n'
                                     '        RunBookConnectors\n'
                                     '        type\n'
                                     '        longSave\n'
                                     '        rbVars\n'
                                     '        scope\n'
                                     '        PeopleCanView\n'
                                     '        PeopleCanAccess\n'
                                     '        GroupsCanView\n'
                                     '        GroupsCanAccess\n'
                                     '      }\n'
                                     '    }\n'
                                     '  }\n',
 'ondeleteschedpbs': '\n'
                     '  subscription OnDeleteSchedPBs {\n'
                     '    onDeleteSchedPBs {\n'
                     '      id\n'
                     '      pbId\n'
                     '      frequency\n'
                     '      pbName\n'
                     '      rbVars\n'
                     '      scheduled\n'
                     '      createdAt\n'
                     '      updatedAt\n'
                     '      author\n'
                     '    }\n'
                     '  }\n',
 'ondeletesshtabs': '\n'
                    '  subscription OnDeleteSshTabs {\n'
                    '    onDeleteSshTabs {\n'
                    '      id\n'
                    '      investigationId\n'
                    '      host\n'
                    '      author\n'
                    '      userName\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '    }\n'
                    '  }\n',
 'ondeletestash': '\n'
                  '  subscription OnDeleteStash {\n'
                  '    onDeleteStash {\n'
                  '      id\n'
                  '      Key\n'
                  '      Value\n'
                  '      createdAt\n'
                  '      updatedAt\n'
                  '      author\n'
                  '      scope\n'
                  '      PeopleCanView\n'
                  '      PeopleCanAccess\n'
                  '      GroupsCanView\n'
                  '      GroupsCanAccess\n'
                  '    }\n'
                  '  }\n',
 'ondeletestate': '\n'
                  '  subscription OnDeleteState {\n'
                  '    onDeleteState {\n'
                  '      id\n'
                  '      name\n'
                  '      createdAt\n'
                  '      updatedAt\n'
                  '      author\n'
                  '      lastState\n'
                  '      investigationId\n'
                  '      investigation {\n'
                  '        id\n'
                  '        title\n'
                  '        from\n'
                  '        createdAt\n'
                  '        currentState\n'
                  '        HumanID\n'
                  '        currentStateID\n'
                  '        severity\n'
                  '        priority\n'
                  '        location\n'
                  '        channelId\n'
                  '        updatedAt\n'
                  '        resolvedTime\n'
                  '        resolvedComment\n'
                  '        Symptoms\n'
                  '        meetingType\n'
                  '        meetingId\n'
                  '      }\n'
                  '    }\n'
                  '  }\n',
 'ondeletesummaryinvestigation': '\n'
                                 '  subscription '
                                 'OnDeleteSummaryInvestigation($owner: String) '
                                 '{\n'
                                 '    onDeleteSummaryInvestigation(owner: '
                                 '$owner) {\n'
                                 '      id\n'
                                 '      createdAt\n'
                                 '      updatedAt\n'
                                 '      resolvedTime\n'
                                 '      OriginalID\n'
                                 '      title\n'
                                 '      HumanID\n'
                                 '      Commands\n'
                                 '      InvestigationEvents\n'
                                 '      CompleteInvestigationEvents\n'
                                 '      Participants\n'
                                 '      Comments\n'
                                 '      Pins\n'
                                 '      AvailableRunbooks\n'
                                 '      UsedRunbooks\n'
                                 '      Hints\n'
                                 '      Symptoms\n'
                                 '      owner\n'
                                 '    }\n'
                                 '  }\n',
 'ondeletetenantcustomer': '\n'
                           '  subscription OnDeleteTenantCustomer {\n'
                           '    onDeleteTenantCustomer {\n'
                           '      label\n'
                           '      impactLabels\n'
                           '      createdAt\n'
                           '      updatedAt\n'
                           '      customerName\n'
                           '      email\n'
                           '      phoneno\n'
                           '      SLAType\n'
                           '      city\n'
                           '      state\n'
                           '      contry\n'
                           '      zipcode\n'
                           '    }\n'
                           '  }\n',
 'ondeletetranscriptionrecords': '\n'
                                 '  subscription OnDeleteTranscriptionRecords '
                                 '{\n'
                                 '    onDeleteTranscriptionRecords {\n'
                                 '      id\n'
                                 '      investigationId\n'
                                 '      createdAt\n'
                                 '      updatedAt\n'
                                 '      spokenBy\n'
                                 '      content\n'
                                 '    }\n'
                                 '  }\n',
 'ondeleteusedtogenhintalready': '\n'
                                 '  subscription OnDeleteUsedToGenHintAlready '
                                 '{\n'
                                 '    onDeleteUsedToGenHintAlready {\n'
                                 '      id\n'
                                 '      createdAt\n'
                                 '      updatedAt\n'
                                 '      investigationId\n'
                                 '      commands\n'
                                 '      text\n'
                                 '      investigation {\n'
                                 '        id\n'
                                 '        title\n'
                                 '        from\n'
                                 '        createdAt\n'
                                 '        currentState\n'
                                 '        HumanID\n'
                                 '        currentStateID\n'
                                 '        severity\n'
                                 '        priority\n'
                                 '        location\n'
                                 '        channelId\n'
                                 '        updatedAt\n'
                                 '        resolvedTime\n'
                                 '        resolvedComment\n'
                                 '        Symptoms\n'
                                 '        meetingType\n'
                                 '        meetingId\n'
                                 '      }\n'
                                 '    }\n'
                                 '  }\n',
 'ondeleteuser': '\n'
                 '  subscription OnDeleteUser($owner: String) {\n'
                 '    onDeleteUser(owner: $owner) {\n'
                 '      id\n'
                 '      username\n'
                 '      email\n'
                 '      firstname\n'
                 '      lastname\n'
                 '      avatar\n'
                 '      mood\n'
                 '      name\n'
                 '      role\n'
                 '      status\n'
                 '      timezone\n'
                 '      phone\n'
                 '      address\n'
                 '      location\n'
                 '      chatList {\n'
                 '        nextToken\n'
                 '      }\n'
                 '      messages {\n'
                 '        nextToken\n'
                 '      }\n'
                 '      createdAt\n'
                 '      updatedAt\n'
                 '      owner\n'
                 '    }\n'
                 '  }\n',
 'ondeleteuseractivity': '\n'
                         '  subscription OnDeleteUserActivity {\n'
                         '    onDeleteUserActivity {\n'
                         '      id\n'
                         '      userID\n'
                         '      status\n'
                         '      investigationID\n'
                         '      createdAt\n'
                         '      updatedAt\n'
                         '      investigation {\n'
                         '        id\n'
                         '        title\n'
                         '        from\n'
                         '        createdAt\n'
                         '        currentState\n'
                         '        HumanID\n'
                         '        currentStateID\n'
                         '        severity\n'
                         '        priority\n'
                         '        location\n'
                         '        channelId\n'
                         '        updatedAt\n'
                         '        resolvedTime\n'
                         '        resolvedComment\n'
                         '        Symptoms\n'
                         '        meetingType\n'
                         '        meetingId\n'
                         '      }\n'
                         '      user {\n'
                         '        id\n'
                         '        username\n'
                         '        email\n'
                         '        firstname\n'
                         '        lastname\n'
                         '        avatar\n'
                         '        mood\n'
                         '        name\n'
                         '        role\n'
                         '        status\n'
                         '        timezone\n'
                         '        phone\n'
                         '        address\n'
                         '        location\n'
                         '        createdAt\n'
                         '        updatedAt\n'
                         '        owner\n'
                         '      }\n'
                         '    }\n'
                         '  }\n',
 'ondeleteusersettinglabellink': '\n'
                                 '  subscription OnDeleteUserSettingLabelLink '
                                 '{\n'
                                 '    onDeleteUserSettingLabelLink {\n'
                                 '      id\n'
                                 '      userSettingId\n'
                                 '      userSetting {\n'
                                 '        id\n'
                                 '        userId\n'
                                 '        owner\n'
                                 '        createdAt\n'
                                 '        updatedAt\n'
                                 '        value\n'
                                 '        url\n'
                                 '        name\n'
                                 '        type\n'
                                 '        showWelcomeNext\n'
                                 '        showWelcomeSkip\n'
                                 '        showWelcomeRemind\n'
                                 '        welcomeData\n'
                                 '      }\n'
                                 '      labelID\n'
                                 '      label {\n'
                                 '        id\n'
                                 '        name\n'
                                 '        color\n'
                                 '        type\n'
                                 '      }\n'
                                 '      type\n'
                                 '    }\n'
                                 '  }\n',
 'onupdatealertapikey': '\n'
                        '  subscription OnUpdateAlertApiKey {\n'
                        '    onUpdateAlertApiKey {\n'
                        '      id\n'
                        '      alertsPbName\n'
                        '      createdAt\n'
                        '      updatedAt\n'
                        '      author\n'
                        '    }\n'
                        '  }\n',
 'onupdateallrunbooks': '\n'
                        '  subscription OnUpdateAllRunbooks {\n'
                        '    onUpdateAllRunbooks {\n'
                        '      id\n'
                        '      name\n'
                        '      description\n'
                        '      content\n'
                        '      author\n'
                        '      commands\n'
                        '      createdAt\n'
                        '      updatedAt\n'
                        '      RunBookConnectors\n'
                        '      type\n'
                        '      longSave\n'
                        '      rbVars\n'
                        '      scope\n'
                        '      PeopleCanView\n'
                        '      PeopleCanAccess\n'
                        '      GroupsCanView\n'
                        '      GroupsCanAccess\n'
                        '      connectorForms {\n'
                        '        nextToken\n'
                        '      }\n'
                        '    }\n'
                        '  }\n',
 'onupdateallworkflows': '\n'
                         '  subscription OnUpdateAllWorkflows {\n'
                         '    onUpdateAllWorkflows {\n'
                         '      id\n'
                         '      createdAt\n'
                         '      updatedAt\n'
                         '      name\n'
                         '      description\n'
                         '      type\n'
                         '      author\n'
                         '      longSave\n'
                         '      rbVars\n'
                         '    }\n'
                         '  }\n',
 'onupdatebase64image': '\n'
                        '  subscription OnUpdateBase64Image {\n'
                        '    onUpdateBase64Image {\n'
                        '      id\n'
                        '      playbookID\n'
                        '      base64String\n'
                        '    }\n'
                        '  }\n',
 'onupdatechannel': '\n'
                    '  subscription OnUpdateChannel {\n'
                    '    onUpdateChannel {\n'
                    '      id\n'
                    '      messages {\n'
                    '        nextToken\n'
                    '      }\n'
                    '      associated {\n'
                    '        nextToken\n'
                    '      }\n'
                    '      name\n'
                    '      title\n'
                    '      members\n'
                    '      membersState\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '      memberLocation\n'
                    '    }\n'
                    '  }\n',
 'onupdatechat': '\n'
                 '  subscription OnUpdateChat {\n'
                 '    onUpdateChat {\n'
                 '      id\n'
                 '      from\n'
                 '      content\n'
                 '      createdAt\n'
                 '    }\n'
                 '  }\n',
 'onupdatecheatsheet': '\n'
                       '  subscription OnUpdateCheatSheet {\n'
                       '    onUpdateCheatSheet {\n'
                       '      id\n'
                       '      createdAt\n'
                       '      updatedAt\n'
                       '      title\n'
                       '      author\n'
                       '      content\n'
                       '      type\n'
                       '    }\n'
                       '  }\n',
 'onupdatechecklist': '\n'
                      '  subscription OnUpdateCheckList {\n'
                      '    onUpdateCheckList {\n'
                      '      id\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '      name\n'
                      '      description\n'
                      '      type\n'
                      '      content\n'
                      '      author\n'
                      '      CheckListLink {\n'
                      '        nextToken\n'
                      '      }\n'
                      '      CheckListInvLink {\n'
                      '        nextToken\n'
                      '      }\n'
                      '    }\n'
                      '  }\n',
 'onupdatechecklistinvlink': '\n'
                             '  subscription OnUpdateCheckListInvLink($owner: '
                             'String) {\n'
                             '    onUpdateCheckListInvLink(owner: $owner) {\n'
                             '      id\n'
                             '      createdAt\n'
                             '      updatedAt\n'
                             '      investigationID\n'
                             '      CheckListID\n'
                             '      CheckList {\n'
                             '        id\n'
                             '        createdAt\n'
                             '        updatedAt\n'
                             '        name\n'
                             '        description\n'
                             '        type\n'
                             '        content\n'
                             '        author\n'
                             '      }\n'
                             '      investigation {\n'
                             '        id\n'
                             '        title\n'
                             '        from\n'
                             '        createdAt\n'
                             '        currentState\n'
                             '        HumanID\n'
                             '        currentStateID\n'
                             '        severity\n'
                             '        priority\n'
                             '        location\n'
                             '        channelId\n'
                             '        updatedAt\n'
                             '        resolvedTime\n'
                             '        resolvedComment\n'
                             '        Symptoms\n'
                             '        meetingType\n'
                             '        meetingId\n'
                             '      }\n'
                             '      owner\n'
                             '    }\n'
                             '  }\n',
 'onupdatechecklistitem': '\n'
                          '  subscription OnUpdateCheckListItem {\n'
                          '    onUpdateCheckListItem {\n'
                          '      id\n'
                          '      localID\n'
                          '      createdAt\n'
                          '      updatedAt\n'
                          '      author\n'
                          '      content\n'
                          '      title\n'
                          '      type\n'
                          '      connection\n'
                          '      MMNodeConnection\n'
                          '      investigationID\n'
                          '      assignee\n'
                          '      associatedPlaybooks\n'
                          '      associatedCommands\n'
                          '      CheckListLink {\n'
                          '        nextToken\n'
                          '      }\n'
                          '    }\n'
                          '  }\n',
 'onupdateclick': '\n'
                  '  subscription OnUpdateClick {\n'
                  '    onUpdateClick {\n'
                  '      id\n'
                  '      count\n'
                  '      type\n'
                  '      featureName\n'
                  '      createdAt\n'
                  '      updatedAt\n'
                  '      readAt\n'
                  '    }\n'
                  '  }\n',
 'onupdateclicllink': '\n'
                      '  subscription OnUpdateCliclLink($author: String) {\n'
                      '    onUpdateCLICLLink(author: $author) {\n'
                      '      id\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '      CheckListItemID\n'
                      '      lane\n'
                      '      CheckListID\n'
                      '      CheckList {\n'
                      '        id\n'
                      '        createdAt\n'
                      '        updatedAt\n'
                      '        name\n'
                      '        description\n'
                      '        type\n'
                      '        content\n'
                      '        author\n'
                      '      }\n'
                      '      CheckListItem {\n'
                      '        id\n'
                      '        localID\n'
                      '        createdAt\n'
                      '        updatedAt\n'
                      '        author\n'
                      '        content\n'
                      '        title\n'
                      '        type\n'
                      '        connection\n'
                      '        MMNodeConnection\n'
                      '        investigationID\n'
                      '        assignee\n'
                      '        associatedPlaybooks\n'
                      '        associatedCommands\n'
                      '      }\n'
                      '    }\n'
                      '  }\n',
 'onupdatecommands': '\n'
                     '  subscription OnUpdateCommands {\n'
                     '    onUpdateCommands {\n'
                     '      id\n'
                     '      from\n'
                     '      mode\n'
                     '      command\n'
                     '      output\n'
                     '      state\n'
                     '      returnCode\n'
                     '      investigationId\n'
                     '      createdAt\n'
                     '      updatedAt\n'
                     '      investigation {\n'
                     '        id\n'
                     '        title\n'
                     '        from\n'
                     '        createdAt\n'
                     '        currentState\n'
                     '        HumanID\n'
                     '        currentStateID\n'
                     '        severity\n'
                     '        priority\n'
                     '        location\n'
                     '        channelId\n'
                     '        updatedAt\n'
                     '        resolvedTime\n'
                     '        resolvedComment\n'
                     '        Symptoms\n'
                     '        meetingType\n'
                     '        meetingId\n'
                     '      }\n'
                     '    }\n'
                     '  }\n',
 'onupdatecomment': '\n'
                    '  subscription OnUpdateComment {\n'
                    '    onUpdateComment {\n'
                    '      id\n'
                    '      parent\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '      author\n'
                    '      content\n'
                    '      type\n'
                    '      links\n'
                    '      investigationId\n'
                    '      investigation {\n'
                    '        id\n'
                    '        title\n'
                    '        from\n'
                    '        createdAt\n'
                    '        currentState\n'
                    '        HumanID\n'
                    '        currentStateID\n'
                    '        severity\n'
                    '        priority\n'
                    '        location\n'
                    '        channelId\n'
                    '        updatedAt\n'
                    '        resolvedTime\n'
                    '        resolvedComment\n'
                    '        Symptoms\n'
                    '        meetingType\n'
                    '        meetingId\n'
                    '      }\n'
                    '    }\n'
                    '  }\n',
 'onupdateconferenceconfig': '\n'
                             '  subscription OnUpdateConferenceConfig {\n'
                             '    onUpdateConferenceConfig {\n'
                             '      id\n'
                             '      url\n'
                             '      userName\n'
                             '      password\n'
                             '      author\n'
                             '      createdAt\n'
                             '      updatedAt\n'
                             '    }\n'
                             '  }\n',
 'onupdateconnectorform': '\n'
                          '  subscription OnUpdateConnectorForm {\n'
                          '    onUpdateConnectorForm {\n'
                          '      id\n'
                          '      createdAt\n'
                          '      updatedAt\n'
                          '      name\n'
                          '      owner\n'
                          '      connectorID\n'
                          '      connector {\n'
                          '        id\n'
                          '        createdAt\n'
                          '        updatedAt\n'
                          '        category\n'
                          '        name\n'
                          '        owner\n'
                          '        description\n'
                          '        detaileddescription\n'
                          '        iconPath\n'
                          '        version\n'
                          '        md5\n'
                          '        source\n'
                          '        configuration\n'
                          '        commands\n'
                          '        commandsType\n'
                          '        script\n'
                          '        scriptType\n'
                          '        scriptPath\n'
                          '        scope\n'
                          '        PeopleCanView\n'
                          '        PeopleCanAccess\n'
                          '        GroupsCanView\n'
                          '        GroupsCanAccess\n'
                          '      }\n'
                          '      configData\n'
                          '      commandData\n'
                          '      nodeData\n'
                          '      scope\n'
                          '      PeopleCanView\n'
                          '      PeopleCanAccess\n'
                          '      GroupsCanView\n'
                          '      GroupsCanAccess\n'
                          '      runbooks {\n'
                          '        nextToken\n'
                          '      }\n'
                          '    }\n'
                          '  }\n',
 'onupdateconnectors': '\n'
                       '  subscription OnUpdateConnectors {\n'
                       '    onUpdateConnectors {\n'
                       '      id\n'
                       '      createdAt\n'
                       '      updatedAt\n'
                       '      category\n'
                       '      name\n'
                       '      owner\n'
                       '      description\n'
                       '      detaileddescription\n'
                       '      iconPath\n'
                       '      version\n'
                       '      md5\n'
                       '      source\n'
                       '      configuration\n'
                       '      commands\n'
                       '      commandsType\n'
                       '      script\n'
                       '      scriptType\n'
                       '      scriptPath\n'
                       '      scope\n'
                       '      PeopleCanView\n'
                       '      PeopleCanAccess\n'
                       '      GroupsCanView\n'
                       '      GroupsCanAccess\n'
                       '    }\n'
                       '  }\n',
 'onupdatedashboardconfig': '\n'
                            '  subscription OnUpdateDashboardConfig {\n'
                            '    onUpdateDashboardConfig {\n'
                            '      id\n'
                            '      url\n'
                            '      labels {\n'
                            '        nextToken\n'
                            '      }\n'
                            '      author\n'
                            '      createdAt\n'
                            '      updatedAt\n'
                            '    }\n'
                            '  }\n',
 'onupdateecubesandboxexecution': '\n'
                                  '  subscription '
                                  'OnUpdateEcubeSandboxExecution {\n'
                                  '    onUpdateEcubeSandboxExecution {\n'
                                  '      id\n'
                                  '      owner\n'
                                  '      output\n'
                                  '      outputType\n'
                                  '      returnCode\n'
                                  '      status\n'
                                  '      createdAt\n'
                                  '      updatedAt\n'
                                  '      E3One\n'
                                  '      E3Two\n'
                                  '      E3Three\n'
                                  '    }\n'
                                  '  }\n',
 'onupdateepicautocomplete': '\n'
                             '  subscription OnUpdateEpicAutoComplete($author: '
                             'String) {\n'
                             '    onUpdateEpicAutoComplete(author: $author) {\n'
                             '      id\n'
                             '      author\n'
                             '      cliCommand\n'
                             '      command\n'
                             '      createdAt\n'
                             '      updatedAt\n'
                             '      investigationId\n'
                             '      times\n'
                             '    }\n'
                             '  }\n',
 'onupdateepiclicommand': '\n'
                          '  subscription OnUpdateEpicliCommand {\n'
                          '    onUpdateEPICLICommand {\n'
                          '      id\n'
                          '      createdAt\n'
                          '      updatedAt\n'
                          '      author\n'
                          '      content\n'
                          '      type\n'
                          '    }\n'
                          '  }\n',
 'onupdateexecutedrunbooks': '\n'
                             '  subscription OnUpdateExecutedRunbooks {\n'
                             '    onUpdateExecutedRunbooks {\n'
                             '      id\n'
                             '      createdAt\n'
                             '      updatedAt\n'
                             '      runbookID\n'
                             '      investigationId\n'
                             '      output\n'
                             '      outputType\n'
                             '      title\n'
                             '      state\n'
                             '      author\n'
                             '      rbVars\n'
                             '      callbackUrl\n'
                             '      callbackData\n'
                             '      source\n'
                             '      investigation {\n'
                             '        id\n'
                             '        title\n'
                             '        from\n'
                             '        createdAt\n'
                             '        currentState\n'
                             '        HumanID\n'
                             '        currentStateID\n'
                             '        severity\n'
                             '        priority\n'
                             '        location\n'
                             '        channelId\n'
                             '        updatedAt\n'
                             '        resolvedTime\n'
                             '        resolvedComment\n'
                             '        Symptoms\n'
                             '        meetingType\n'
                             '        meetingId\n'
                             '      }\n'
                             '      runbook {\n'
                             '        id\n'
                             '        name\n'
                             '        description\n'
                             '        content\n'
                             '        author\n'
                             '        commands\n'
                             '        createdAt\n'
                             '        updatedAt\n'
                             '        RunBookConnectors\n'
                             '        type\n'
                             '        longSave\n'
                             '        rbVars\n'
                             '        scope\n'
                             '        PeopleCanView\n'
                             '        PeopleCanAccess\n'
                             '        GroupsCanView\n'
                             '        GroupsCanAccess\n'
                             '      }\n'
                             '    }\n'
                             '  }\n',
 'onupdateexecutedworkflowstate': '\n'
                                  '  subscription '
                                  'OnUpdateExecutedWorkflowState {\n'
                                  '    onUpdateExecutedWorkflowState {\n'
                                  '      id\n'
                                  '      createdAt\n'
                                  '      updatedAt\n'
                                  '      name\n'
                                  '      state\n'
                                  '      output\n'
                                  '      type\n'
                                  '      allworkflowID\n'
                                  '      investigationID\n'
                                  '      investigation {\n'
                                  '        id\n'
                                  '        title\n'
                                  '        from\n'
                                  '        createdAt\n'
                                  '        currentState\n'
                                  '        HumanID\n'
                                  '        currentStateID\n'
                                  '        severity\n'
                                  '        priority\n'
                                  '        location\n'
                                  '        channelId\n'
                                  '        updatedAt\n'
                                  '        resolvedTime\n'
                                  '        resolvedComment\n'
                                  '        Symptoms\n'
                                  '        meetingType\n'
                                  '        meetingId\n'
                                  '      }\n'
                                  '    }\n'
                                  '  }\n',
 'onupdategroupmember': '\n'
                        '  subscription OnUpdateGroupMember {\n'
                        '    onUpdateGroupMember {\n'
                        '      id\n'
                        '      hostId\n'
                        '      groupId\n'
                        '      host {\n'
                        '        id\n'
                        '        inventoryId\n'
                        '        createdAt\n'
                        '        updatedAt\n'
                        '        author\n'
                        '        host\n'
                        '        port\n'
                        '        vars\n'
                        '      }\n'
                        '      group {\n'
                        '        id\n'
                        '        inventoryId\n'
                        '        createdAt\n'
                        '        updatedAt\n'
                        '        author\n'
                        '        name\n'
                        '        groups\n'
                        '        port\n'
                        '        vars\n'
                        '      }\n'
                        '    }\n'
                        '  }\n',
 'onupdateguardrail': '\n'
                      '  subscription OnUpdateGuardRail {\n'
                      '    onUpdateGuardRail {\n'
                      '      id\n'
                      '      timeOut\n'
                      '      message\n'
                      '      labels {\n'
                      '        nextToken\n'
                      '      }\n'
                      '      author\n'
                      '      active\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '    }\n'
                      '  }\n',
 'onupdatehint': '\n'
                 '  subscription OnUpdateHint {\n'
                 '    onUpdateHint {\n'
                 '      id\n'
                 '      investigationId\n'
                 '      createdAt\n'
                 '      updatedAt\n'
                 '      type\n'
                 '      connection\n'
                 '      pastInvestigationID\n'
                 '      title\n'
                 '      importance\n'
                 '      starrted\n'
                 '      applied\n'
                 '      url\n'
                 '      why\n'
                 '    }\n'
                 '  }\n',
 'onupdateinventory': '\n'
                      '  subscription OnUpdateInventory {\n'
                      '    onUpdateInventory {\n'
                      '      id\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '      author\n'
                      '      name\n'
                      '      all {\n'
                      '        nextToken\n'
                      '      }\n'
                      '      groups {\n'
                      '        nextToken\n'
                      '      }\n'
                      '      vars\n'
                      '    }\n'
                      '  }\n',
 'onupdateinventorygroup': '\n'
                           '  subscription OnUpdateInventoryGroup {\n'
                           '    onUpdateInventoryGroup {\n'
                           '      id\n'
                           '      inventoryId\n'
                           '      createdAt\n'
                           '      updatedAt\n'
                           '      author\n'
                           '      name\n'
                           '      hosts {\n'
                           '        nextToken\n'
                           '      }\n'
                           '      groups\n'
                           '      port\n'
                           '      vars\n'
                           '      inventory {\n'
                           '        id\n'
                           '        createdAt\n'
                           '        updatedAt\n'
                           '        author\n'
                           '        name\n'
                           '        vars\n'
                           '      }\n'
                           '    }\n'
                           '  }\n',
 'onupdateinventoryhost': '\n'
                          '  subscription OnUpdateInventoryHost {\n'
                          '    onUpdateInventoryHost {\n'
                          '      id\n'
                          '      inventoryId\n'
                          '      createdAt\n'
                          '      updatedAt\n'
                          '      author\n'
                          '      host\n'
                          '      port\n'
                          '      vars\n'
                          '      groups {\n'
                          '        nextToken\n'
                          '      }\n'
                          '      inventory {\n'
                          '        id\n'
                          '        createdAt\n'
                          '        updatedAt\n'
                          '        author\n'
                          '        name\n'
                          '        vars\n'
                          '      }\n'
                          '    }\n'
                          '  }\n',
 'onupdateinvestigation': '\n'
                          '  subscription OnUpdateInvestigation {\n'
                          '    onUpdateInvestigation {\n'
                          '      id\n'
                          '      title\n'
                          '      from\n'
                          '      createdAt\n'
                          '      currentState\n'
                          '      HumanID\n'
                          '      currentStateID\n'
                          '      severity\n'
                          '      priority\n'
                          '      location\n'
                          '      labels {\n'
                          '        nextToken\n'
                          '      }\n'
                          '      channelId\n'
                          '      investigationChannel {\n'
                          '        id\n'
                          '        name\n'
                          '        title\n'
                          '        members\n'
                          '        membersState\n'
                          '        createdAt\n'
                          '        updatedAt\n'
                          '        memberLocation\n'
                          '      }\n'
                          '      updatedAt\n'
                          '      resolvedTime\n'
                          '      resolvedComment\n'
                          '      Symptoms\n'
                          '      MMNodeLinks {\n'
                          '        nextToken\n'
                          '      }\n'
                          '      CheckListInvLink {\n'
                          '        nextToken\n'
                          '      }\n'
                          '      meetingType\n'
                          '      meetingId\n'
                          '    }\n'
                          '  }\n',
 'onupdateinvestigationevent': '\n'
                               '  subscription OnUpdateInvestigationEvent {\n'
                               '    onUpdateInvestigationEvent {\n'
                               '      id\n'
                               '      createdAt\n'
                               '      updatedAt\n'
                               '      author\n'
                               '      content\n'
                               '      type\n'
                               '      links\n'
                               '      investigationId\n'
                               '      investigation {\n'
                               '        id\n'
                               '        title\n'
                               '        from\n'
                               '        createdAt\n'
                               '        currentState\n'
                               '        HumanID\n'
                               '        currentStateID\n'
                               '        severity\n'
                               '        priority\n'
                               '        location\n'
                               '        channelId\n'
                               '        updatedAt\n'
                               '        resolvedTime\n'
                               '        resolvedComment\n'
                               '        Symptoms\n'
                               '        meetingType\n'
                               '        meetingId\n'
                               '      }\n'
                               '    }\n'
                               '  }\n',
 'onupdateinvestigationguestuserlink': '\n'
                                       '  subscription '
                                       'OnUpdateInvestigationGuestUserLink {\n'
                                       '    onUpdateInvestigationGuestUserLink '
                                       '{\n'
                                       '      id\n'
                                       '      userName\n'
                                       '      createdAt\n'
                                       '      updatedAt\n'
                                       '      investigationID\n'
                                       '      channelID\n'
                                       '    }\n'
                                       '  }\n',
 'onupdatelabel': '\n'
                  '  subscription OnUpdateLabel {\n'
                  '    onUpdateLabel {\n'
                  '      id\n'
                  '      name\n'
                  '      color\n'
                  '      type\n'
                  '      investigations {\n'
                  '        nextToken\n'
                  '      }\n'
                  '      userSettings {\n'
                  '        nextToken\n'
                  '      }\n'
                  '    }\n'
                  '  }\n',
 'onupdateleadboard': '\n'
                      '  subscription OnUpdateLeadBoard {\n'
                      '    onUpdateLeadBoard {\n'
                      '      id\n'
                      '      investigationId\n'
                      '      content\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '      investigation {\n'
                      '        id\n'
                      '        title\n'
                      '        from\n'
                      '        createdAt\n'
                      '        currentState\n'
                      '        HumanID\n'
                      '        currentStateID\n'
                      '        severity\n'
                      '        priority\n'
                      '        location\n'
                      '        channelId\n'
                      '        updatedAt\n'
                      '        resolvedTime\n'
                      '        resolvedComment\n'
                      '        Symptoms\n'
                      '        meetingType\n'
                      '        meetingId\n'
                      '      }\n'
                      '    }\n'
                      '  }\n',
 'onupdateleadboardnode': '\n'
                          '  subscription OnUpdateLeadBoardNode {\n'
                          '    onUpdateLeadBoardNode {\n'
                          '      id\n'
                          '      localID\n'
                          '      createdAt\n'
                          '      updatedAt\n'
                          '      author\n'
                          '      content\n'
                          '      title\n'
                          '      notes\n'
                          '      associatedPlaybooks\n'
                          '      associatedCommands\n'
                          '      InvestLinks {\n'
                          '        nextToken\n'
                          '      }\n'
                          '    }\n'
                          '  }\n',
 'onupdatemessage': '\n'
                    '  subscription OnUpdateMessage {\n'
                    '    onUpdateMessage {\n'
                    '      id\n'
                    '      authorId\n'
                    '      content\n'
                    '      type\n'
                    '      channel {\n'
                    '        id\n'
                    '        name\n'
                    '        title\n'
                    '        members\n'
                    '        membersState\n'
                    '        createdAt\n'
                    '        updatedAt\n'
                    '        memberLocation\n'
                    '      }\n'
                    '      messageChannelId\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '      author {\n'
                    '        id\n'
                    '        username\n'
                    '        email\n'
                    '        firstname\n'
                    '        lastname\n'
                    '        avatar\n'
                    '        mood\n'
                    '        name\n'
                    '        role\n'
                    '        status\n'
                    '        timezone\n'
                    '        phone\n'
                    '        address\n'
                    '        location\n'
                    '        createdAt\n'
                    '        updatedAt\n'
                    '        owner\n'
                    '      }\n'
                    '    }\n'
                    '  }\n',
 'onupdatemmnodelink': '\n'
                       '  subscription OnUpdateMmNodeLink {\n'
                       '    onUpdateMMNodeLink {\n'
                       '      id\n'
                       '      createdAt\n'
                       '      updatedAt\n'
                       '      assigned\n'
                       '      state\n'
                       '      content\n'
                       '      author\n'
                       '      investigationID\n'
                       '      connectionToTask\n'
                       '      LBNID\n'
                       '      LeadBoardNodeId {\n'
                       '        id\n'
                       '        localID\n'
                       '        createdAt\n'
                       '        updatedAt\n'
                       '        author\n'
                       '        content\n'
                       '        title\n'
                       '        notes\n'
                       '        associatedPlaybooks\n'
                       '        associatedCommands\n'
                       '      }\n'
                       '      investigationId {\n'
                       '        id\n'
                       '        title\n'
                       '        from\n'
                       '        createdAt\n'
                       '        currentState\n'
                       '        HumanID\n'
                       '        currentStateID\n'
                       '        severity\n'
                       '        priority\n'
                       '        location\n'
                       '        channelId\n'
                       '        updatedAt\n'
                       '        resolvedTime\n'
                       '        resolvedComment\n'
                       '        Symptoms\n'
                       '        meetingType\n'
                       '        meetingId\n'
                       '      }\n'
                       '    }\n'
                       '  }\n',
 'onupdatenotification': '\n'
                         '  subscription OnUpdateNotification {\n'
                         '    onUpdateNotification {\n'
                         '      id\n'
                         '      userName\n'
                         '      content\n'
                         '      containerType\n'
                         '      containerId\n'
                         '      investigationId\n'
                         '      isViewed\n'
                         '      createdAt\n'
                         '      updatedAt\n'
                         '    }\n'
                         '  }\n',
 'onupdatepin': '\n'
                '  subscription OnUpdatePin {\n'
                '    onUpdatePin {\n'
                '      id\n'
                '      imageId\n'
                '      content\n'
                '      createdAt\n'
                '      updatedAt\n'
                '      author\n'
                '      investigationId\n'
                '      investigation {\n'
                '        id\n'
                '        title\n'
                '        from\n'
                '        createdAt\n'
                '        currentState\n'
                '        HumanID\n'
                '        currentStateID\n'
                '        severity\n'
                '        priority\n'
                '        location\n'
                '        channelId\n'
                '        updatedAt\n'
                '        resolvedTime\n'
                '        resolvedComment\n'
                '        Symptoms\n'
                '        meetingType\n'
                '        meetingId\n'
                '      }\n'
                '    }\n'
                '  }\n',
 'onupdateprivatekey': '\n'
                       '  subscription OnUpdatePrivateKey {\n'
                       '    onUpdatePrivateKey {\n'
                       '      id\n'
                       '      sshKey\n'
                       '      userName\n'
                       '      createdAt\n'
                       '      updatedAt\n'
                       '    }\n'
                       '  }\n',
 'onupdateremotecontrol': '\n'
                          '  subscription OnUpdateRemoteControl {\n'
                          '    onUpdateRemoteControl {\n'
                          '      id\n'
                          '      from\n'
                          '      to\n'
                          '      command\n'
                          '      createdAt\n'
                          '      updatedAt\n'
                          '    }\n'
                          '  }\n',
 'onupdatereportsummaryeditor': '\n'
                                '  subscription OnUpdateReportSummaryEditor {\n'
                                '    onUpdateReportSummaryEditor {\n'
                                '      id\n'
                                '      investigationId\n'
                                '      createdAt\n'
                                '      updatedAt\n'
                                '      author\n'
                                '      content\n'
                                '      type\n'
                                '    }\n'
                                '  }\n',
 'onupdaterunbookconnectorformlink': '\n'
                                     '  subscription '
                                     'OnUpdateRunbookConnectorFormLink {\n'
                                     '    onUpdateRunbookConnectorFormLink {\n'
                                     '      id\n'
                                     '      connectorFormId\n'
                                     '      runbookId\n'
                                     '      connectorForm {\n'
                                     '        id\n'
                                     '        createdAt\n'
                                     '        updatedAt\n'
                                     '        name\n'
                                     '        owner\n'
                                     '        connectorID\n'
                                     '        configData\n'
                                     '        commandData\n'
                                     '        nodeData\n'
                                     '        scope\n'
                                     '        PeopleCanView\n'
                                     '        PeopleCanAccess\n'
                                     '        GroupsCanView\n'
                                     '        GroupsCanAccess\n'
                                     '      }\n'
                                     '      runbook {\n'
                                     '        id\n'
                                     '        name\n'
                                     '        description\n'
                                     '        content\n'
                                     '        author\n'
                                     '        commands\n'
                                     '        createdAt\n'
                                     '        updatedAt\n'
                                     '        RunBookConnectors\n'
                                     '        type\n'
                                     '        longSave\n'
                                     '        rbVars\n'
                                     '        scope\n'
                                     '        PeopleCanView\n'
                                     '        PeopleCanAccess\n'
                                     '        GroupsCanView\n'
                                     '        GroupsCanAccess\n'
                                     '      }\n'
                                     '    }\n'
                                     '  }\n',
 'onupdateschedpbs': '\n'
                     '  subscription OnUpdateSchedPBs {\n'
                     '    onUpdateSchedPBs {\n'
                     '      id\n'
                     '      pbId\n'
                     '      frequency\n'
                     '      pbName\n'
                     '      rbVars\n'
                     '      scheduled\n'
                     '      createdAt\n'
                     '      updatedAt\n'
                     '      author\n'
                     '    }\n'
                     '  }\n',
 'onupdatesshtabs': '\n'
                    '  subscription OnUpdateSshTabs {\n'
                    '    onUpdateSshTabs {\n'
                    '      id\n'
                    '      investigationId\n'
                    '      host\n'
                    '      author\n'
                    '      userName\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '    }\n'
                    '  }\n',
 'onupdatestash': '\n'
                  '  subscription OnUpdateStash {\n'
                  '    onUpdateStash {\n'
                  '      id\n'
                  '      Key\n'
                  '      Value\n'
                  '      createdAt\n'
                  '      updatedAt\n'
                  '      author\n'
                  '      scope\n'
                  '      PeopleCanView\n'
                  '      PeopleCanAccess\n'
                  '      GroupsCanView\n'
                  '      GroupsCanAccess\n'
                  '    }\n'
                  '  }\n',
 'onupdatestate': '\n'
                  '  subscription OnUpdateState {\n'
                  '    onUpdateState {\n'
                  '      id\n'
                  '      name\n'
                  '      createdAt\n'
                  '      updatedAt\n'
                  '      author\n'
                  '      lastState\n'
                  '      investigationId\n'
                  '      investigation {\n'
                  '        id\n'
                  '        title\n'
                  '        from\n'
                  '        createdAt\n'
                  '        currentState\n'
                  '        HumanID\n'
                  '        currentStateID\n'
                  '        severity\n'
                  '        priority\n'
                  '        location\n'
                  '        channelId\n'
                  '        updatedAt\n'
                  '        resolvedTime\n'
                  '        resolvedComment\n'
                  '        Symptoms\n'
                  '        meetingType\n'
                  '        meetingId\n'
                  '      }\n'
                  '    }\n'
                  '  }\n',
 'onupdatesummaryinvestigation': '\n'
                                 '  subscription '
                                 'OnUpdateSummaryInvestigation($owner: String) '
                                 '{\n'
                                 '    onUpdateSummaryInvestigation(owner: '
                                 '$owner) {\n'
                                 '      id\n'
                                 '      createdAt\n'
                                 '      updatedAt\n'
                                 '      resolvedTime\n'
                                 '      OriginalID\n'
                                 '      title\n'
                                 '      HumanID\n'
                                 '      Commands\n'
                                 '      InvestigationEvents\n'
                                 '      CompleteInvestigationEvents\n'
                                 '      Participants\n'
                                 '      Comments\n'
                                 '      Pins\n'
                                 '      AvailableRunbooks\n'
                                 '      UsedRunbooks\n'
                                 '      Hints\n'
                                 '      Symptoms\n'
                                 '      owner\n'
                                 '    }\n'
                                 '  }\n',
 'onupdatetenantcustomer': '\n'
                           '  subscription OnUpdateTenantCustomer {\n'
                           '    onUpdateTenantCustomer {\n'
                           '      label\n'
                           '      impactLabels\n'
                           '      createdAt\n'
                           '      updatedAt\n'
                           '      customerName\n'
                           '      email\n'
                           '      phoneno\n'
                           '      SLAType\n'
                           '      city\n'
                           '      state\n'
                           '      contry\n'
                           '      zipcode\n'
                           '    }\n'
                           '  }\n',
 'onupdatetranscriptionrecords': '\n'
                                 '  subscription OnUpdateTranscriptionRecords '
                                 '{\n'
                                 '    onUpdateTranscriptionRecords {\n'
                                 '      id\n'
                                 '      investigationId\n'
                                 '      createdAt\n'
                                 '      updatedAt\n'
                                 '      spokenBy\n'
                                 '      content\n'
                                 '    }\n'
                                 '  }\n',
 'onupdateusedtogenhintalready': '\n'
                                 '  subscription OnUpdateUsedToGenHintAlready '
                                 '{\n'
                                 '    onUpdateUsedToGenHintAlready {\n'
                                 '      id\n'
                                 '      createdAt\n'
                                 '      updatedAt\n'
                                 '      investigationId\n'
                                 '      commands\n'
                                 '      text\n'
                                 '      investigation {\n'
                                 '        id\n'
                                 '        title\n'
                                 '        from\n'
                                 '        createdAt\n'
                                 '        currentState\n'
                                 '        HumanID\n'
                                 '        currentStateID\n'
                                 '        severity\n'
                                 '        priority\n'
                                 '        location\n'
                                 '        channelId\n'
                                 '        updatedAt\n'
                                 '        resolvedTime\n'
                                 '        resolvedComment\n'
                                 '        Symptoms\n'
                                 '        meetingType\n'
                                 '        meetingId\n'
                                 '      }\n'
                                 '    }\n'
                                 '  }\n',
 'onupdateuser': '\n'
                 '  subscription OnUpdateUser($owner: String) {\n'
                 '    onUpdateUser(owner: $owner) {\n'
                 '      id\n'
                 '      username\n'
                 '      email\n'
                 '      firstname\n'
                 '      lastname\n'
                 '      avatar\n'
                 '      mood\n'
                 '      name\n'
                 '      role\n'
                 '      status\n'
                 '      timezone\n'
                 '      phone\n'
                 '      address\n'
                 '      location\n'
                 '      chatList {\n'
                 '        nextToken\n'
                 '      }\n'
                 '      messages {\n'
                 '        nextToken\n'
                 '      }\n'
                 '      createdAt\n'
                 '      updatedAt\n'
                 '      owner\n'
                 '    }\n'
                 '  }\n',
 'onupdateuseractivity': '\n'
                         '  subscription OnUpdateUserActivity {\n'
                         '    onUpdateUserActivity {\n'
                         '      id\n'
                         '      userID\n'
                         '      status\n'
                         '      investigationID\n'
                         '      createdAt\n'
                         '      updatedAt\n'
                         '      investigation {\n'
                         '        id\n'
                         '        title\n'
                         '        from\n'
                         '        createdAt\n'
                         '        currentState\n'
                         '        HumanID\n'
                         '        currentStateID\n'
                         '        severity\n'
                         '        priority\n'
                         '        location\n'
                         '        channelId\n'
                         '        updatedAt\n'
                         '        resolvedTime\n'
                         '        resolvedComment\n'
                         '        Symptoms\n'
                         '        meetingType\n'
                         '        meetingId\n'
                         '      }\n'
                         '      user {\n'
                         '        id\n'
                         '        username\n'
                         '        email\n'
                         '        firstname\n'
                         '        lastname\n'
                         '        avatar\n'
                         '        mood\n'
                         '        name\n'
                         '        role\n'
                         '        status\n'
                         '        timezone\n'
                         '        phone\n'
                         '        address\n'
                         '        location\n'
                         '        createdAt\n'
                         '        updatedAt\n'
                         '        owner\n'
                         '      }\n'
                         '    }\n'
                         '  }\n',
 'onupdateusersettinglabellink': '\n'
                                 '  subscription OnUpdateUserSettingLabelLink '
                                 '{\n'
                                 '    onUpdateUserSettingLabelLink {\n'
                                 '      id\n'
                                 '      userSettingId\n'
                                 '      userSetting {\n'
                                 '        id\n'
                                 '        userId\n'
                                 '        owner\n'
                                 '        createdAt\n'
                                 '        updatedAt\n'
                                 '        value\n'
                                 '        url\n'
                                 '        name\n'
                                 '        type\n'
                                 '        showWelcomeNext\n'
                                 '        showWelcomeSkip\n'
                                 '        showWelcomeRemind\n'
                                 '        welcomeData\n'
                                 '      }\n'
                                 '      labelID\n'
                                 '      label {\n'
                                 '        id\n'
                                 '        name\n'
                                 '        color\n'
                                 '        type\n'
                                 '      }\n'
                                 '      type\n'
                                 '    }\n'
                                 '  }\n',
 'subscribetooneinvestigation': '\n'
                                '  subscription '
                                'SubscribeToOneInvestigation($id: ID) {\n'
                                '    subscribeToOneInvestigation(id: $id) {\n'
                                '      id\n'
                                '      title\n'
                                '      from\n'
                                '      createdAt\n'
                                '      currentState\n'
                                '      HumanID\n'
                                '      currentStateID\n'
                                '      severity\n'
                                '      priority\n'
                                '      location\n'
                                '      labels {\n'
                                '        nextToken\n'
                                '      }\n'
                                '      channelId\n'
                                '      investigationChannel {\n'
                                '        id\n'
                                '        name\n'
                                '        title\n'
                                '        members\n'
                                '        membersState\n'
                                '        createdAt\n'
                                '        updatedAt\n'
                                '        memberLocation\n'
                                '      }\n'
                                '      updatedAt\n'
                                '      resolvedTime\n'
                                '      resolvedComment\n'
                                '      Symptoms\n'
                                '      MMNodeLinks {\n'
                                '        nextToken\n'
                                '      }\n'
                                '      CheckListInvLink {\n'
                                '        nextToken\n'
                                '      }\n'
                                '      meetingType\n'
                                '      meetingId\n'
                                '    }\n'
                                '  }\n'}
